@@ -89,6 +89,10 @@ export async function embedDashboard({
 
   log('embedding');
 
+  if (supersetDomain.endsWith("/")) {
+    supersetDomain = supersetDomain.slice(0, -1);
+  }
+
   function calculateConfig() {
     let configNumber = 0
     if(dashboardUiConfig) {
@@ -150,6 +154,7 @@ export async function embedDashboard({
       });
 
       iframe.src = `${supersetDomain}/embedded/${id}${dashboardConfig}${filterConfigUrlParams}`;
+      //@ts-ignore
       mountPoint.replaceChildren(iframe);
       log('placed the iframe')
     });
@@ -173,6 +178,7 @@ export async function embedDashboard({
 
   function unmount() {
     log('unmounting');
+    //@ts-ignore
     mountPoint.replaceChildren();
   }
 
