@@ -17,6 +17,8 @@
  * under the License.
  */
 import { buildQueryContext } from '@superset-ui/core';
+import * as queryModule from '../../src/query/normalizeTimeColumn';
+import * as getXAxisModule from '../../src/query/getXAxis';
 
 describe('buildQueryContext', () => {
   it('should build datasource for table sources and apply defaults', () => {
@@ -31,17 +33,6 @@ describe('buildQueryContext', () => {
     expect(queryContext.result_format).toBe('json');
     expect(queryContext.result_type).toBe('full');
   });
-  it('should build datasource for druid sources and set force to true', () => {
-    const queryContext = buildQueryContext({
-      datasource: '5__druid',
-      granularity: 'ds',
-      viz_type: 'table',
-      force: true,
-    });
-    expect(queryContext.datasource.id).toBe(5);
-    expect(queryContext.datasource.type).toBe('druid');
-    expect(queryContext.force).toBe(true);
-  });
   it('should build datasource for table sources with columns', () => {
     const queryContext = buildQueryContext(
       {
@@ -108,6 +99,7 @@ describe('buildQueryContext', () => {
       ]),
     );
   });
+  // todo(Yongjie): move these test case into buildQueryObject.test.ts
   it('should remove undefined value in post_processing', () => {
     const queryContext = buildQueryContext(
       {
@@ -133,4 +125,43 @@ describe('buildQueryContext', () => {
       },
     ]);
   });
+  it('should call normalizeTimeColumn if GENERIC_CHART_AXES is enabled and has x_axis', () => {
+    Object.defineProperty(getXAxisModule, 'hasGenericChartAxes', {
+      value: true,
+    });
+    const spyNormalizeTimeColumn = jest.spyOn(
+      queryModule,
+      'normalizeTimeColumn',
+    );
+
+    buildQueryContext(
+      {
+        datasource: '5__table',
+        viz_type: 'table',
+        x_axis: 'axis',
+      },
+      () => [{}],
+    );
+    expect(spyNormalizeTimeColumn).toBeCalled();
+    spyNormalizeTimeColumn.mockRestore();
+  });
+  it("shouldn't call normalizeTimeColumn if GENERIC_CHART_AXES is disabled", () => {
+    Object.defineProperty(getXAxisModule, 'hasGenericChartAxes', {
+      value: false,
+    });
+    const spyNormalizeTimeColumn = jest.spyOn(
+      queryModule,
+      'normalizeTimeColumn',
+    );
+
+    buildQueryContext(
+      {
+        datasource: '5__table',
+        viz_type: 'table',
+      },
+      () => [{}],
+    );
+    expect(spyNormalizeTimeColumn).not.toBeCalled();
+    spyNormalizeTimeColumn.mockRestore();
+  });
 });
