@@ -40,10 +40,15 @@ function setTooltipContent(o) {
   return (
     <div className="deckgl-tooltip">
       <TooltipRow
-        label={`${t('Longitude and Latitude')}: `}
+        // eslint-disable-next-line prefer-template
+        label={t('Longitude and Latitude') + ': '}
         value={`${o.coordinate[0]}, ${o.coordinate[1]}`}
       />
-      <TooltipRow label={`${t('Weight')}: `} value={`${o.object.cellWeight}`} />
+      <TooltipRow
+        // eslint-disable-next-line prefer-template
+        label={t('Weight') + ': '}
+        value={`${o.object.cellWeight}`}
+      />
     </div>
   );
 }
