@@ -25,8 +25,6 @@ export { default as BubbleChartPlugin } from './Bubble';
 export { default as BulletChartPlugin } from './Bullet';
 export { default as CompareChartPlugin } from './Compare';
 export { default as DistBarChartPlugin } from './DistBar';
-export { default as DualLineChartPlugin } from './DualLine';
 export { default as LineChartPlugin } from './Line';
-export { default as LineMultiChartPlugin } from './LineMulti';
 export { default as PieChartPlugin } from './Pie';
 export { default as TimePivotChartPlugin } from './TimePivot';
