@@ -18,10 +18,16 @@
  */
 
 import React from 'react';
-import { render, screen, waitFor, within } from 'spec/helpers/testing-library';
-import { queryClient } from 'src/views/QueryProvider';
-import fetchMock from 'fetch-mock';
 import { act } from 'react-dom/test-utils';
+import {
+  render,
+  screen,
+  waitFor,
+  within,
+  defaultStore as store,
+} from 'spec/helpers/testing-library';
+import { api } from 'src/hooks/apiResources/queryApi';
+import fetchMock from 'fetch-mock';
 import userEvent from '@testing-library/user-event';
 import TableSelector, { TableSelectorMultiple } from '.';
 
@@ -36,11 +42,6 @@ const createProps = (props = {}) => ({
   ...props,
 });
 
-const getSchemaMockFunction = () =>
-  ({
-    result: ['schema_a', 'schema_b'],
-  } as any);
-
 const getTableMockFunction = () =>
   ({
     count: 4,
@@ -62,11 +63,13 @@ const getSelectItemContainer = (select: HTMLElement) =>
   );
 
 beforeEach(() => {
-  queryClient.clear();
   fetchMock.get(databaseApiRoute, { result: [] });
 });
 
 afterEach(() => {
+  act(() => {
+    store.dispatch(api.util.resetApiState());
+  });
   fetchMock.reset();
 });
 
@@ -75,15 +78,15 @@ test('renders with default props', async () => {
   fetchMock.get(tablesApiRoute, getTableMockFunction());
 
   const props = createProps();
-  render(<TableSelector {...props} />, { useRedux: true });
+  render(<TableSelector {...props} />, { useRedux: true, store });
   const databaseSelect = screen.getByRole('combobox', {
-    name: 'Select database or type database name',
+    name: 'Select database or type to search databases',
   });
   const schemaSelect = screen.getByRole('combobox', {
-    name: 'Select schema or type schema name',
+    name: 'Select schema or type to search schemas',
   });
   const tableSelect = screen.getByRole('combobox', {
-    name: 'Select table or type table name',
+    name: 'Select table or type to search tables',
   });
   await waitFor(() => {
     expect(databaseSelect).toBeInTheDocument();
@@ -92,14 +95,33 @@ test('renders with default props', async () => {
   });
 });
 
-test('renders table options', async () => {
+test('skips select all options', async () => {
   fetchMock.get(schemaApiRoute, { result: ['test_schema'] });
   fetchMock.get(tablesApiRoute, getTableMockFunction());
 
   const props = createProps();
-  render(<TableSelector {...props} />, { useRedux: true });
+  render(<TableSelector {...props} tableSelectMode="multiple" />, {
+    useRedux: true,
+    store,
+  });
   const tableSelect = screen.getByRole('combobox', {
-    name: 'Select table or type table name',
+    name: 'Select table or type to search tables',
+  });
+  userEvent.click(tableSelect);
+  expect(
+    await screen.findByRole('option', { name: 'table_a' }),
+  ).toBeInTheDocument();
+  expect(screen.queryByRole('option', { name: /Select All/i })).toBeFalsy();
+});
+
+test('renders table options without Select All option', async () => {
+  fetchMock.get(schemaApiRoute, { result: ['test_schema'] });
+  fetchMock.get(tablesApiRoute, getTableMockFunction());
+
+  const props = createProps();
+  render(<TableSelector {...props} />, { useRedux: true, store });
+  const tableSelect = screen.getByRole('combobox', {
+    name: 'Select table or type to search tables',
   });
   userEvent.click(tableSelect);
   expect(
@@ -115,56 +137,18 @@ test('renders disabled without schema', async () => {
   fetchMock.get(tablesApiRoute, getTableMockFunction());
 
   const props = createProps();
-  render(<TableSelector {...props} schema={undefined} />, { useRedux: true });
+  render(<TableSelector {...props} schema={undefined} />, {
+    useRedux: true,
+    store,
+  });
   const tableSelect = screen.getByRole('combobox', {
-    name: 'Select table or type table name',
+    name: 'Select table or type to search tables',
   });
   await waitFor(() => {
     expect(tableSelect).toBeDisabled();
   });
 });
 
-test('table options are notified after schema selection', async () => {
-  fetchMock.get(schemaApiRoute, getSchemaMockFunction());
-
-  const callback = jest.fn();
-  const props = createProps({
-    onTablesLoad: callback,
-    schema: undefined,
-  });
-  render(<TableSelector {...props} />, { useRedux: true });
-
-  const schemaSelect = screen.getByRole('combobox', {
-    name: 'Select schema or type schema name',
-  });
-  expect(schemaSelect).toBeInTheDocument();
-  expect(callback).not.toHaveBeenCalled();
-
-  userEvent.click(schemaSelect);
-
-  expect(
-    await screen.findByRole('option', { name: 'schema_a' }),
-  ).toBeInTheDocument();
-  expect(
-    await screen.findByRole('option', { name: 'schema_b' }),
-  ).toBeInTheDocument();
-
-  fetchMock.get(tablesApiRoute, getTableMockFunction());
-
-  act(() => {
-    userEvent.click(screen.getAllByText('schema_a')[1]);
-  });
-
-  await waitFor(() => {
-    expect(callback).toHaveBeenCalledWith([
-      { label: 'table_a', value: 'table_a' },
-      { label: 'table_b', value: 'table_b' },
-      { label: 'table_c', value: 'table_c' },
-      { label: 'table_d', value: 'table_d' },
-    ]);
-  });
-});
-
 test('table select retain value if not in SQL Lab mode', async () => {
   fetchMock.get(schemaApiRoute, { result: ['test_schema'] });
   fetchMock.get(tablesApiRoute, getTableMockFunction());
@@ -175,10 +159,10 @@ test('table select retain value if not in SQL Lab mode', async () => {
     sqlLabMode: false,
   });
 
-  render(<TableSelector {...props} />, { useRedux: true });
+  render(<TableSelector {...props} />, { useRedux: true, store });
 
   const tableSelect = screen.getByRole('combobox', {
-    name: 'Select table or type table name',
+    name: 'Select table or type to search tables',
   });
 
   expect(screen.queryByText('table_a')).not.toBeInTheDocument();
@@ -215,10 +199,10 @@ test('table multi select retain all the values selected', async () => {
     onTableSelectChange: callback,
   });
 
-  render(<TableSelectorMultiple {...props} />, { useRedux: true });
+  render(<TableSelectorMultiple {...props} />, { useRedux: true, store });
 
   const tableSelect = screen.getByRole('combobox', {
-    name: 'Select table or type table name',
+    name: 'Select table or type to search tables',
   });
 
   expect(screen.queryByText('table_a')).not.toBeInTheDocument();
