@@ -24,8 +24,12 @@ import userEvent from '@testing-library/user-event';
 import fetchMock from 'fetch-mock';
 import { HeaderDropdownProps } from 'src/dashboard/components/Header/types';
 import injectCustomCss from 'src/dashboard/util/injectCustomCss';
+import { FeatureFlag } from '@superset-ui/core';
+import * as uiCore from '@superset-ui/core';
 import HeaderActionsDropdown from '.';
 
+let isFeatureEnabledMock: jest.MockInstance<boolean, [feature: FeatureFlag]>;
+
 const createProps = () => ({
   addSuccessToast: jest.fn(),
   addDangerToast: jest.fn(),
@@ -70,11 +74,24 @@ const createProps = () => ({
   dataMask: {},
   logEvent: jest.fn(),
 });
+
 const editModeOnProps = {
   ...createProps(),
   editMode: true,
 };
 
+const editModeOnWithFilterScopesProps = {
+  ...editModeOnProps,
+  dashboardInfo: {
+    ...editModeOnProps.dashboardInfo,
+    metadata: {
+      filter_scopes: {
+        '1': { scopes: ['ROOT_ID'], immune: [] },
+      },
+    },
+  },
+};
+
 function setup(props: HeaderDropdownProps) {
   return render(
     <div className="dashboard-header">
@@ -112,11 +129,62 @@ test('should render the menu items in edit mode', async () => {
   setup(editModeOnProps);
   expect(screen.getAllByRole('menuitem')).toHaveLength(4);
   expect(screen.getByText('Set auto-refresh interval')).toBeInTheDocument();
-  expect(screen.getByText('Set filter mapping')).toBeInTheDocument();
   expect(screen.getByText('Edit properties')).toBeInTheDocument();
   expect(screen.getByText('Edit CSS')).toBeInTheDocument();
 });
 
+describe('with native filters feature flag disabled', () => {
+  beforeAll(() => {
+    isFeatureEnabledMock = jest
+      .spyOn(uiCore, 'isFeatureEnabled')
+      .mockImplementation(
+        (featureFlag: FeatureFlag) =>
+          featureFlag !== FeatureFlag.DASHBOARD_NATIVE_FILTERS,
+      );
+  });
+
+  afterAll(() => {
+    // @ts-ignore
+    isFeatureEnabledMock.restore();
+  });
+
+  it('should render filter mapping in edit mode if explicit filter scopes undefined', async () => {
+    setup(editModeOnProps);
+    expect(screen.getByText('Set filter mapping')).toBeInTheDocument();
+  });
+
+  it('should render filter mapping in edit mode if explicit filter scopes defined', async () => {
+    setup(editModeOnWithFilterScopesProps);
+    expect(screen.getByText('Set filter mapping')).toBeInTheDocument();
+  });
+});
+
+describe('with native filters feature flag enabled', () => {
+  beforeAll(() => {
+    isFeatureEnabledMock = jest
+      .spyOn(uiCore, 'isFeatureEnabled')
+      .mockImplementation(
+        (featureFlag: FeatureFlag) =>
+          featureFlag === FeatureFlag.DASHBOARD_NATIVE_FILTERS,
+      );
+  });
+
+  afterAll(() => {
+    // @ts-ignore
+    isFeatureEnabledMock.restore();
+  });
+
+  it('should not render filter mapping in edit mode if explicit filter scopes undefined', async () => {
+    setup(editModeOnProps);
+    expect(screen.queryByText('Set filter mapping')).not.toBeInTheDocument();
+  });
+
+  it('should render filter mapping in edit mode if explicit filter scopes defined', async () => {
+    setup(editModeOnWithFilterScopesProps);
+    expect(screen.getByText('Set filter mapping')).toBeInTheDocument();
+  });
+});
+
 test('should show the share actions', async () => {
   const mockedProps = createProps();
   const canShareProps = {
@@ -128,7 +196,7 @@ test('should show the share actions', async () => {
   expect(screen.getByText('Share')).toBeInTheDocument();
 });
 
-test('should render the "Save Modal" when user can save', async () => {
+test('should render the "Save as" menu item when user can save', async () => {
   const mockedProps = createProps();
   const canSaveProps = {
     ...mockedProps,
@@ -138,7 +206,7 @@ test('should render the "Save Modal" when user can save', async () => {
   expect(screen.getByText('Save as')).toBeInTheDocument();
 });
 
-test('should NOT render the "Save Modal" menu item when user cannot save', async () => {
+test('should NOT render the "Save as" menu item when user cannot save', async () => {
   const mockedProps = createProps();
   setup(mockedProps);
   expect(screen.queryByText('Save as')).not.toBeInTheDocument();
