@@ -112,6 +112,7 @@ const HorizontalOverflowFilterControlContainer = styled(
 
 const VerticalFormItem = styled(StyledFormItem)`
   .ant-form-item-label {
+    overflow: visible;
     label.ant-form-item-required:not(.ant-form-item-required-mark-optional) {
       &::after {
         display: none;
@@ -127,6 +128,7 @@ const HorizontalFormItem = styled(StyledFormItem)`
   }
 
   .ant-form-item-label {
+    overflow: visible;
     padding-bottom: 0;
     margin-right: ${({ theme }) => theme.gridUnit * 2}px;
     label.ant-form-item-required:not(.ant-form-item-required-mark-optional) {
@@ -200,10 +202,11 @@ const DescriptionToolTip = ({ description }: { description: string }) => (
       placement="right"
       overlayInnerStyle={{
         display: '-webkit-box',
-        overflow: 'hidden',
-        WebkitLineClamp: 20,
+        WebkitLineClamp: 10,
         WebkitBoxOrient: 'vertical',
+        overflow: 'hidden',
         textOverflow: 'ellipsis',
+        whiteSpace: 'normal',
       }}
       getPopupContainer={trigger => trigger.parentElement as HTMLElement}
     >
