@@ -17,6 +17,7 @@
  * under the License.
  */
 import React from 'react';
+import userEvent from '@testing-library/user-event';
 import { render, screen } from 'spec/helpers/testing-library';
 import { DndItemType } from 'src/explore/components/DndItemType';
 import DndSelectLabel, {
@@ -29,27 +30,35 @@ const defaultProps: DndSelectLabelProps = {
   onDrop: jest.fn(),
   canDrop: () => false,
   valuesRenderer: () => <span />,
+  ghostButtonText: 'Drop columns here or click',
+  onClickGhostButton: jest.fn(),
 };
 
-test('renders with default props', async () => {
+test('renders with default props', () => {
   render(<DndSelectLabel {...defaultProps} />, { useDnd: true });
-  expect(await screen.findByText('Drop columns here')).toBeInTheDocument();
+  expect(screen.getByText('Drop columns here or click')).toBeInTheDocument();
 });
 
-test('renders ghost button when empty', async () => {
+test('renders ghost button when empty', () => {
   const ghostButtonText = 'Ghost button text';
   render(
     <DndSelectLabel {...defaultProps} ghostButtonText={ghostButtonText} />,
     { useDnd: true },
   );
-  expect(await screen.findByText(ghostButtonText)).toBeInTheDocument();
+  expect(screen.getByText(ghostButtonText)).toBeInTheDocument();
 });
 
-test('renders values', async () => {
+test('renders values', () => {
   const values = 'Values';
   const valuesRenderer = () => <span>{values}</span>;
   render(<DndSelectLabel {...defaultProps} valuesRenderer={valuesRenderer} />, {
     useDnd: true,
   });
-  expect(await screen.findByText(values)).toBeInTheDocument();
+  expect(screen.getByText(values)).toBeInTheDocument();
+});
+
+test('Handles ghost button click', () => {
+  render(<DndSelectLabel {...defaultProps} />, { useDnd: true });
+  userEvent.click(screen.getByText('Drop columns here or click'));
+  expect(defaultProps.onClickGhostButton).toHaveBeenCalled();
 });
