@@ -31,11 +31,14 @@ const propTypes = {
   disabled: PropTypes.bool,
   freeForm: PropTypes.bool,
   isLoading: PropTypes.bool,
+  mode: PropTypes.string,
   multi: PropTypes.bool,
   isMulti: PropTypes.bool,
   name: PropTypes.string.isRequired,
   onChange: PropTypes.func,
   onFocus: PropTypes.func,
+  onSelect: PropTypes.func,
+  onDeselect: PropTypes.func,
   value: PropTypes.oneOfType([
     PropTypes.string,
     PropTypes.number,
@@ -174,12 +177,14 @@ export default class SelectControl extends React.PureComponent {
       label,
       multi,
       name,
-      placeholder,
-      onFocus,
-      showHeader,
-      value,
-      tokenSeparators,
       notFoundContent,
+      onFocus,
+      onSelect,
+      onDeselect,
+      placeholder,
+      showHeader,
+      tokenSeparators,
+      value,
       // ControlHeader props
       description,
       renderTrigger,
@@ -236,10 +241,12 @@ export default class SelectControl extends React.PureComponent {
           : true,
       header: showHeader && <ControlHeader {...headerProps} />,
       loading: isLoading,
-      mode: isMulti || multi ? 'multiple' : 'single',
+      mode: this.props.mode || (isMulti || multi ? 'multiple' : 'single'),
       name: `select-${name}`,
       onChange: this.onChange,
       onFocus,
+      onSelect,
+      onDeselect,
       options: this.state.options,
       placeholder,
       sortComparator: this.props.sortComparator,
