@@ -39,7 +39,6 @@ export enum Operators {
   NOT_IN = 'NOT_IN',
   LIKE = 'LIKE',
   ILIKE = 'ILIKE',
-  REGEX = 'REGEX',
   IS_NOT_NULL = 'IS_NOT_NULL',
   IS_NULL = 'IS_NULL',
   LATEST_PARTITION = 'LATEST_PARTITION',
@@ -75,7 +74,6 @@ export const OPERATOR_ENUM_TO_OPERATOR_TYPE: {
     display: t('Like (case insensitive)'),
     operation: 'ILIKE',
   },
-  [Operators.REGEX]: { display: t('Regex'), operation: 'REGEX' },
   [Operators.IS_NOT_NULL]: {
     display: t('Is not null'),
     operation: 'IS NOT NULL',
@@ -125,8 +123,6 @@ export const sqlaAutoGeneratedMetricNameRegex =
   /^(sum|min|max|avg|count|count_distinct)__.*$/i;
 export const sqlaAutoGeneratedMetricRegex =
   /^(LONG|DOUBLE|FLOAT)?(SUM|AVG|MAX|MIN|COUNT)\([A-Z0-9_."]*\)$/i;
-export const druidAutoGeneratedMetricRegex =
-  /^(LONG|DOUBLE|FLOAT)?(SUM|MAX|MIN|COUNT)\([A-Z0-9_."]*\)$/i;
 
 export const TIME_FILTER_LABELS = {
   time_range: t('Time range'),
@@ -156,18 +152,6 @@ export const TIME_FILTER_MAP = {
   granularity: '__granularity',
 };
 
-export enum FILTER_BOX_MIGRATION_STATES {
-  CONVERTED = 'CONVERTED',
-  NOOP = 'NOOP',
-  REVIEWING = 'REVIEWING',
-  SNOOZED = 'SNOOZED',
-  UNDECIDED = 'UNDECIDED',
-}
-
-export const FILTER_BOX_TRANSITION_SNOOZE_DURATION = 24 * 60 * 60 * 1000; // 24 hours
-
 export const POPOVER_INITIAL_HEIGHT = 240;
 export const POPOVER_INITIAL_WIDTH = 320;
-export const UNRESIZABLE_POPOVER_WIDTH = 296;
-
 export const UNSAVED_CHART_ID = 0;
