@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Dict, List, Set, Tuple
+from typing import Any
 
 from marshmallow import Schema
 from sqlalchemy.orm import Session
@@ -27,7 +27,7 @@ from superset.charts.commands.importers.v1.utils import import_chart
 from superset.charts.schemas import ImportV1ChartSchema
 from superset.commands.exceptions import CommandException
 from superset.commands.importers.v1 import ImportModelsCommand
-from superset.dao.base import BaseDAO
+from superset.daos.base import BaseDAO
 from superset.dashboards.commands.importers.v1 import ImportDashboardsCommand
 from superset.dashboards.commands.importers.v1.utils import (
     find_chart_uuids,
@@ -52,7 +52,7 @@ class ImportExamplesCommand(ImportModelsCommand):
 
     dao = BaseDAO
     model_name = "model"
-    schemas: Dict[str, Schema] = {
+    schemas: dict[str, Schema] = {
         "charts/": ImportV1ChartSchema(),
         "dashboards/": ImportV1DashboardSchema(),
         "datasets/": ImportV1DatasetSchema(),
@@ -60,7 +60,7 @@ class ImportExamplesCommand(ImportModelsCommand):
     }
     import_error = CommandException
 
-    def __init__(self, contents: Dict[str, str], *args: Any, **kwargs: Any):
+    def __init__(self, contents: dict[str, str], *args: Any, **kwargs: Any):
         super().__init__(contents, *args, **kwargs)
         self.force_data = kwargs.get("force_data", False)
 
@@ -81,7 +81,7 @@ class ImportExamplesCommand(ImportModelsCommand):
             raise self.import_error() from ex
 
     @classmethod
-    def _get_uuids(cls) -> Set[str]:
+    def _get_uuids(cls) -> set[str]:
         # pylint: disable=protected-access
         return (
             ImportDatabasesCommand._get_uuids()
@@ -93,12 +93,12 @@ class ImportExamplesCommand(ImportModelsCommand):
     @staticmethod
     def _import(  # pylint: disable=arguments-differ, too-many-locals, too-many-branches
         session: Session,
-        configs: Dict[str, Any],
+        configs: dict[str, Any],
         overwrite: bool = False,
         force_data: bool = False,
     ) -> None:
         # import databases
-        database_ids: Dict[str, int] = {}
+        database_ids: dict[str, int] = {}
         for file_name, config in configs.items():
             if file_name.startswith("databases/"):
                 database = import_database(
@@ -114,7 +114,7 @@ class ImportExamplesCommand(ImportModelsCommand):
         # database was created before its UUID was frozen, so it has a random UUID.
         # We need to determine its ID so we can point the dataset to it.
         examples_db = get_example_database()
-        dataset_info: Dict[str, Dict[str, Any]] = {}
+        dataset_info: dict[str, dict[str, Any]] = {}
         for file_name, config in configs.items():
             if file_name.startswith("datasets/"):
                 # find the ID of the corresponding database
@@ -153,7 +153,7 @@ class ImportExamplesCommand(ImportModelsCommand):
                 }
 
         # import charts
-        chart_ids: Dict[str, int] = {}
+        chart_ids: dict[str, int] = {}
         for file_name, config in configs.items():
             if (
                 file_name.startswith("charts/")
@@ -175,7 +175,7 @@ class ImportExamplesCommand(ImportModelsCommand):
         ).fetchall()
 
         # import dashboards
-        dashboard_chart_ids: List[Tuple[int, int]] = []
+        dashboard_chart_ids: list[tuple[int, int]] = []
         for file_name, config in configs.items():
             if file_name.startswith("dashboards/"):
                 try:
