@@ -17,10 +17,9 @@
 """Views used by the SqlAlchemy connector"""
 import logging
 import re
-from typing import Any, cast
 
-from flask import current_app, flash, Markup, redirect
-from flask_appbuilder import CompactCRUDMixin, expose
+from flask import flash, Markup, redirect
+from flask_appbuilder import CompactCRUDMixin, expose, permission_name
 from flask_appbuilder.fields import QuerySelectField
 from flask_appbuilder.fieldwidgets import Select2Widget
 from flask_appbuilder.models.sqla.interface import SQLAInterface
@@ -28,17 +27,17 @@ from flask_appbuilder.security.decorators import has_access
 from flask_babel import lazy_gettext as _
 from wtforms.validators import DataRequired, Regexp
 
-from superset import app, db
+from superset import db
 from superset.connectors.base.views import DatasourceModelView
 from superset.connectors.sqla import models
 from superset.constants import MODEL_VIEW_RW_METHOD_PERMISSION_MAP, RouteMethod
 from superset.superset_typing import FlaskResponse
 from superset.utils import core as utils
 from superset.views.base import (
+    BaseSupersetView,
     DatasourceFilter,
     DeleteMixin,
     ListWidgetWithCheckboxes,
-    SupersetListWidget,
     SupersetModelView,
     YamlExportMixin,
 )
@@ -218,6 +217,7 @@ class SqlMetricInlineView(  # pylint: disable=too-many-ancestors
         "expression",
         "table",
         "d3format",
+        "currency",
         "extra",
         "warning_text",
     ]
@@ -270,107 +270,15 @@ class SqlMetricInlineView(  # pylint: disable=too-many-ancestors
     edit_form_extra_fields = add_form_extra_fields
 
 
-class RowLevelSecurityListWidget(
-    SupersetListWidget
-):  # pylint: disable=too-few-public-methods
-    template = "superset/models/rls/list.html"
+class RowLevelSecurityView(BaseSupersetView):
+    route_base = "/rowlevelsecurity"
+    class_permission_name = "RowLevelSecurity"
 
-    def __init__(self, **kwargs: Any):
-        kwargs["appbuilder"] = current_app.appbuilder
-        super().__init__(**kwargs)
-
-
-class RowLevelSecurityFiltersModelView(  # pylint: disable=too-many-ancestors
-    SupersetModelView, DeleteMixin
-):
-    datamodel = SQLAInterface(models.RowLevelSecurityFilter)
-
-    list_widget = cast(SupersetListWidget, RowLevelSecurityListWidget)
-
-    list_title = _("Row level security filter")
-    show_title = _("Show Row level security filter")
-    add_title = _("Add Row level security filter")
-    edit_title = _("Edit Row level security filter")
-
-    list_columns = [
-        "name",
-        "filter_type",
-        "tables",
-        "roles",
-        "clause",
-        "creator",
-        "modified",
-    ]
-    order_columns = ["name", "filter_type", "clause", "modified"]
-    edit_columns = [
-        "name",
-        "description",
-        "filter_type",
-        "tables",
-        "roles",
-        "group_key",
-        "clause",
-    ]
-    show_columns = edit_columns
-    search_columns = (
-        "name",
-        "description",
-        "filter_type",
-        "tables",
-        "roles",
-        "group_key",
-        "clause",
-    )
-    add_columns = edit_columns
-    base_order = ("changed_on", "desc")
-    description_columns = {
-        "name": _("Choose a unique name"),
-        "description": _("Optionally add a detailed description"),
-        "filter_type": _(
-            "Regular filters add where clauses to queries if a user belongs to a "
-            "role referenced in the filter. Base filters apply filters to all queries "
-            "except the roles defined in the filter, and can be used to define what "
-            "users can see if no RLS filters within a filter group apply to them."
-        ),
-        "tables": _("These are the tables this filter will be applied to."),
-        "roles": _(
-            "For regular filters, these are the roles this filter will be "
-            "applied to. For base filters, these are the roles that the "
-            "filter DOES NOT apply to, e.g. Admin if admin should see all "
-            "data."
-        ),
-        "group_key": _(
-            "Filters with the same group key will be ORed together within the group, "
-            "while different filter groups will be ANDed together. Undefined group "
-            "keys are treated as unique groups, i.e. are not grouped together. "
-            "For example, if a table has three filters, of which two are for "
-            "departments Finance and Marketing (group key = 'department'), and one "
-            "refers to the region Europe (group key = 'region'), the filter clause "
-            "would apply the filter (department = 'Finance' OR department = "
-            "'Marketing') AND (region = 'Europe')."
-        ),
-        "clause": _(
-            "This is the condition that will be added to the WHERE clause. "
-            "For example, to only return rows for a particular client, "
-            "you might define a regular filter with the clause `client_id = 9`. To "
-            "display no rows unless a user belongs to a RLS filter role, a base "
-            "filter can be created with the clause `1 = 0` (always false)."
-        ),
-    }
-    label_columns = {
-        "name": _("Name"),
-        "description": _("Description"),
-        "tables": _("Tables"),
-        "roles": _("Roles"),
-        "clause": _("Clause"),
-        "creator": _("Creator"),
-        "modified": _("Modified"),
-    }
-    validators_columns = {"tables": [SelectDataRequired()]}
-
-    if app.config["RLS_FORM_QUERY_REL_FIELDS"]:
-        add_form_query_rel_fields = app.config["RLS_FORM_QUERY_REL_FIELDS"]
-        edit_form_query_rel_fields = add_form_query_rel_fields
+    @expose("/list/")
+    @has_access
+    @permission_name("read")
+    def list(self) -> FlaskResponse:
+        return super().render_app_template()
 
 
 class TableModelView(  # pylint: disable=too-many-ancestors
@@ -405,6 +313,7 @@ class TableModelView(  # pylint: disable=too-many-ancestors
         "is_sqllab_view",
         "template_params",
         "extra",
+        "normalize_columns",
     ]
     base_filters = [["id", DatasourceFilter, lambda: []]]
     show_columns = edit_columns + ["perm", "slices"]
@@ -471,6 +380,10 @@ class TableModelView(  # pylint: disable=too-many-ancestors
             '}, "warning_markdown": "This is a warning." }`.',
             True,
         ),
+        "normalize_columns": _(
+            "Allow column names to be changed to case insensitive format, "
+            "if supported (e.g. Oracle, Snowflake)."
+        ),
     }
     label_columns = {
         "slices": _("Associated Charts"),
@@ -498,6 +411,7 @@ class TableModelView(  # pylint: disable=too-many-ancestors
         "database": QuerySelectField(
             "Database",
             query_func=lambda: db.session.query(models.Database),
+            get_pk_func=lambda item: item.id,
             widget=Select2Widget(extra_classes="readonly"),
         )
     }
@@ -527,14 +441,20 @@ class TableModelView(  # pylint: disable=too-many-ancestors
     def _delete(self, pk: int) -> None:
         DeleteMixin._delete(self, pk)
 
-    @expose("/edit/<pk>", methods=["GET", "POST"])
+    @expose(
+        "/edit/<pk>",
+        methods=(
+            "GET",
+            "POST",
+        ),
+    )
     @has_access
     def edit(self, pk: str) -> FlaskResponse:
         """Simple hack to redirect to explore view after saving"""
         resp = super().edit(pk)
         if isinstance(resp, str):
             return resp
-        return redirect("/explore/?datasource_type=table&datasource_id={}".format(pk))
+        return redirect(f"/explore/?datasource_type=table&datasource_id={pk}")
 
     @expose("/list/")
     @has_access
