@@ -23,9 +23,9 @@ from flask_appbuilder.models.sqla.interface import SQLAInterface
 from flask_babel import ngettext
 
 from superset.constants import MODEL_API_RW_METHOD_PERMISSION_MAP, RouteMethod
-from superset.css_templates.commands.bulk_delete import BulkDeleteCssTemplateCommand
+from superset.css_templates.commands.delete import DeleteCssTemplateCommand
 from superset.css_templates.commands.exceptions import (
-    CssTemplateBulkDeleteFailedError,
+    CssTemplateDeleteFailedError,
     CssTemplateNotFoundError,
 )
 from superset.css_templates.filters import CssTemplateAllTextFilter
@@ -87,7 +87,7 @@ class CssTemplateRestApi(BaseSupersetModelRestApi):
     openapi_spec_tag = "CSS Templates"
     openapi_spec_methods = openapi_spec_methods_override
 
-    @expose("/", methods=["DELETE"])
+    @expose("/", methods=("DELETE",))
     @protect()
     @safe
     @statsd_metrics
@@ -130,7 +130,7 @@ class CssTemplateRestApi(BaseSupersetModelRestApi):
         """
         item_ids = kwargs["rison"]
         try:
-            BulkDeleteCssTemplateCommand(item_ids).run()
+            DeleteCssTemplateCommand(item_ids).run()
             return self.response(
                 200,
                 message=ngettext(
@@ -141,5 +141,5 @@ class CssTemplateRestApi(BaseSupersetModelRestApi):
             )
         except CssTemplateNotFoundError:
             return self.response_404()
-        except CssTemplateBulkDeleteFailedError as ex:
+        except CssTemplateDeleteFailedError as ex:
             return self.response_422(message=str(ex))
