@@ -19,18 +19,22 @@
 
 import inspect
 import json
-from typing import Any, Dict
+from typing import Any
 
 from flask import current_app
 from flask_babel import lazy_gettext as _
 from marshmallow import EXCLUDE, fields, pre_load, Schema, validates_schema
 from marshmallow.validate import Length, ValidationError
-from marshmallow_enum import EnumField
 from sqlalchemy import MetaData
 
-from superset import db
+from superset import db, is_feature_enabled
 from superset.constants import PASSWORD_MASK
 from superset.databases.commands.exceptions import DatabaseInvalidError
+from superset.databases.ssh_tunnel.commands.exceptions import (
+    SSHTunnelingNotEnabledError,
+    SSHTunnelInvalidCredentials,
+    SSHTunnelMissingCredentials,
+)
 from superset.databases.utils import make_url_safe
 from superset.db_engine_specs import get_engine_spec
 from superset.exceptions import CertificateException, SupersetSecurityException
@@ -238,24 +242,28 @@ class DatabaseParametersSchemaMixin:  # pylint: disable=too-few-public-methods
     When using this mixin make sure that `sqlalchemy_uri` is not required.
     """
 
-    engine = fields.String(allow_none=True, description="SQLAlchemy engine to use")
-    driver = fields.String(allow_none=True, description="SQLAlchemy driver to use")
+    engine = fields.String(
+        allow_none=True, metadata={"description": "SQLAlchemy engine to use"}
+    )
+    driver = fields.String(
+        allow_none=True, metadata={"description": "SQLAlchemy driver to use"}
+    )
     parameters = fields.Dict(
         keys=fields.String(),
         values=fields.Raw(),
-        description="DB-specific parameters for configuration",
+        metadata={"description": "DB-specific parameters for configuration"},
     )
-    configuration_method = EnumField(
+    configuration_method = fields.Enum(
         ConfigurationMethod,
         by_value=True,
-        description=configuration_method_description,
-        missing=ConfigurationMethod.SQLALCHEMY_FORM,
+        metadata={"description": configuration_method_description},
+        load_default=ConfigurationMethod.SQLALCHEMY_FORM,
     )
 
     @pre_load
     def build_sqlalchemy_uri(
-        self, data: Dict[str, Any], **kwargs: Any
-    ) -> Dict[str, Any]:
+        self, data: dict[str, Any], **kwargs: Any
+    ) -> dict[str, Any]:
         """
         Build SQLAlchemy URI from separate parameters.
 
@@ -316,9 +324,9 @@ class DatabaseParametersSchemaMixin:  # pylint: disable=too-few-public-methods
 
 def rename_encrypted_extra(
     self: Schema,
-    data: Dict[str, Any],
+    data: dict[str, Any],
     **kwargs: Any,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """
     Rename ``encrypted_extra`` to ``masked_encrypted_extra``.
 
@@ -336,46 +344,60 @@ class DatabaseValidateParametersSchema(Schema):
 
     rename_encrypted_extra = pre_load(rename_encrypted_extra)
 
-    id = fields.Integer(allow_none=True, description="Database ID (for updates)")
-    engine = fields.String(required=True, description="SQLAlchemy engine to use")
-    driver = fields.String(allow_none=True, description="SQLAlchemy driver to use")
+    id = fields.Integer(
+        allow_none=True, metadata={"description": "Database ID (for updates)"}
+    )
+    engine = fields.String(
+        required=True, metadata={"description": "SQLAlchemy engine to use"}
+    )
+    driver = fields.String(
+        allow_none=True, metadata={"description": "SQLAlchemy driver to use"}
+    )
     parameters = fields.Dict(
         keys=fields.String(),
         values=fields.Raw(allow_none=True),
-        description="DB-specific parameters for configuration",
+        metadata={"description": "DB-specific parameters for configuration"},
     )
     catalog = fields.Dict(
         keys=fields.String(),
         values=fields.Raw(allow_none=True),
-        description="Gsheets specific column for managing label to sheet urls",
+        metadata={
+            "description": "Gsheets specific column for managing label to sheet urls"
+        },
     )
     database_name = fields.String(
-        description=database_name_description,
+        metadata={"description": database_name_description},
         allow_none=True,
         validate=Length(1, 250),
     )
-    impersonate_user = fields.Boolean(description=impersonate_user_description)
-    extra = fields.String(description=extra_description, validate=extra_validator)
+    impersonate_user = fields.Boolean(
+        metadata={"description": impersonate_user_description}
+    )
+    extra = fields.String(
+        metadata={"description": extra_description}, validate=extra_validator
+    )
     masked_encrypted_extra = fields.String(
-        description=encrypted_extra_description,
+        metadata={"description": encrypted_extra_description},
         validate=encrypted_extra_validator,
         allow_none=True,
     )
     server_cert = fields.String(
-        description=server_cert_description,
+        metadata={"description": server_cert_description},
         allow_none=True,
         validate=server_cert_validator,
     )
-    configuration_method = EnumField(
+    configuration_method = fields.Enum(
         ConfigurationMethod,
         by_value=True,
         required=True,
-        description=configuration_method_description,
+        metadata={"description": configuration_method_description},
     )
 
 
 class DatabaseSSHTunnel(Schema):
-    id = fields.Integer(allow_none=True, description="SSH Tunnel ID (for updates)")
+    id = fields.Integer(
+        allow_none=True, metadata={"description": "SSH Tunnel ID (for updates)"}
+    )
     server_address = fields.String()
     server_port = fields.Integer()
     username = fields.String()
@@ -395,41 +417,51 @@ class DatabasePostSchema(Schema, DatabaseParametersSchemaMixin):
     rename_encrypted_extra = pre_load(rename_encrypted_extra)
 
     database_name = fields.String(
-        description=database_name_description,
+        metadata={"description": database_name_description},
         required=True,
         validate=Length(1, 250),
     )
     cache_timeout = fields.Integer(
-        description=cache_timeout_description, allow_none=True
+        metadata={"description": cache_timeout_description}, allow_none=True
     )
-    expose_in_sqllab = fields.Boolean(description=expose_in_sqllab_description)
-    allow_run_async = fields.Boolean(description=allow_run_async_description)
-    allow_file_upload = fields.Boolean(description=allow_file_upload_description)
-    allow_ctas = fields.Boolean(description=allow_ctas_description)
-    allow_cvas = fields.Boolean(description=allow_cvas_description)
-    allow_dml = fields.Boolean(description=allow_dml_description)
+    expose_in_sqllab = fields.Boolean(
+        metadata={"description": expose_in_sqllab_description}
+    )
+    allow_run_async = fields.Boolean(
+        metadata={"description": allow_run_async_description}
+    )
+    allow_file_upload = fields.Boolean(
+        metadata={"description": allow_file_upload_description}
+    )
+    allow_ctas = fields.Boolean(metadata={"description": allow_ctas_description})
+    allow_cvas = fields.Boolean(metadata={"description": allow_cvas_description})
+    allow_dml = fields.Boolean(metadata={"description": allow_dml_description})
     force_ctas_schema = fields.String(
-        description=force_ctas_schema_description,
+        metadata={"description": force_ctas_schema_description},
         allow_none=True,
         validate=Length(0, 250),
     )
-    impersonate_user = fields.Boolean(description=impersonate_user_description)
+    impersonate_user = fields.Boolean(
+        metadata={"description": impersonate_user_description}
+    )
     masked_encrypted_extra = fields.String(
-        description=encrypted_extra_description,
+        metadata={"description": encrypted_extra_description},
         validate=encrypted_extra_validator,
         allow_none=True,
     )
-    extra = fields.String(description=extra_description, validate=extra_validator)
+    extra = fields.String(
+        metadata={"description": extra_description}, validate=extra_validator
+    )
     server_cert = fields.String(
-        description=server_cert_description,
+        metadata={"description": server_cert_description},
         allow_none=True,
         validate=server_cert_validator,
     )
     sqlalchemy_uri = fields.String(
-        description=sqlalchemy_uri_description,
+        metadata={"description": sqlalchemy_uri_description},
         validate=[Length(1, 1024), sqlalchemy_uri_validator],
     )
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
     uuid = fields.String(required=False)
     ssh_tunnel = fields.Nested(DatabaseSSHTunnel, allow_none=True)
@@ -442,67 +474,82 @@ class DatabasePutSchema(Schema, DatabaseParametersSchemaMixin):
     rename_encrypted_extra = pre_load(rename_encrypted_extra)
 
     database_name = fields.String(
-        description=database_name_description,
+        metadata={"description": database_name_description},
         allow_none=True,
         validate=Length(1, 250),
     )
     cache_timeout = fields.Integer(
-        description=cache_timeout_description, allow_none=True
+        metadata={"description": cache_timeout_description}, allow_none=True
     )
-    expose_in_sqllab = fields.Boolean(description=expose_in_sqllab_description)
-    allow_run_async = fields.Boolean(description=allow_run_async_description)
-    allow_file_upload = fields.Boolean(description=allow_file_upload_description)
-    allow_ctas = fields.Boolean(description=allow_ctas_description)
-    allow_cvas = fields.Boolean(description=allow_cvas_description)
-    allow_dml = fields.Boolean(description=allow_dml_description)
+    expose_in_sqllab = fields.Boolean(
+        metadata={"description": expose_in_sqllab_description}
+    )
+    allow_run_async = fields.Boolean(
+        metadata={"description": allow_run_async_description}
+    )
+    allow_file_upload = fields.Boolean(
+        metadata={"description": allow_file_upload_description}
+    )
+    allow_ctas = fields.Boolean(metadata={"description": allow_ctas_description})
+    allow_cvas = fields.Boolean(metadata={"description": allow_cvas_description})
+    allow_dml = fields.Boolean(metadata={"description": allow_dml_description})
     force_ctas_schema = fields.String(
-        description=force_ctas_schema_description,
+        metadata={"description": force_ctas_schema_description},
         allow_none=True,
         validate=Length(0, 250),
     )
-    impersonate_user = fields.Boolean(description=impersonate_user_description)
+    impersonate_user = fields.Boolean(
+        metadata={"description": impersonate_user_description}
+    )
     masked_encrypted_extra = fields.String(
-        description=encrypted_extra_description,
+        metadata={"description": encrypted_extra_description},
         allow_none=True,
         validate=encrypted_extra_validator,
     )
-    extra = fields.String(description=extra_description, validate=extra_validator)
+    extra = fields.String(
+        metadata={"description": extra_description}, validate=extra_validator
+    )
     server_cert = fields.String(
-        description=server_cert_description,
+        metadata={"description": server_cert_description},
         allow_none=True,
         validate=server_cert_validator,
     )
     sqlalchemy_uri = fields.String(
-        description=sqlalchemy_uri_description,
+        metadata={"description": sqlalchemy_uri_description},
         validate=[Length(0, 1024), sqlalchemy_uri_validator],
     )
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
     ssh_tunnel = fields.Nested(DatabaseSSHTunnel, allow_none=True)
+    uuid = fields.String(required=False)
 
 
 class DatabaseTestConnectionSchema(Schema, DatabaseParametersSchemaMixin):
     rename_encrypted_extra = pre_load(rename_encrypted_extra)
 
     database_name = fields.String(
-        description=database_name_description,
+        metadata={"description": database_name_description},
         allow_none=True,
         validate=Length(1, 250),
     )
-    impersonate_user = fields.Boolean(description=impersonate_user_description)
-    extra = fields.String(description=extra_description, validate=extra_validator)
+    impersonate_user = fields.Boolean(
+        metadata={"description": impersonate_user_description}
+    )
+    extra = fields.String(
+        metadata={"description": extra_description}, validate=extra_validator
+    )
     masked_encrypted_extra = fields.String(
-        description=encrypted_extra_description,
+        metadata={"description": encrypted_extra_description},
         validate=encrypted_extra_validator,
         allow_none=True,
     )
     server_cert = fields.String(
-        description=server_cert_description,
+        metadata={"description": server_cert_description},
         allow_none=True,
         validate=server_cert_validator,
     )
     sqlalchemy_uri = fields.String(
-        description=sqlalchemy_uri_description,
+        metadata={"description": sqlalchemy_uri_description},
         validate=[Length(1, 1024), sqlalchemy_uri_validator],
     )
 
@@ -518,20 +565,27 @@ class TableMetadataOptionsResponseSchema(Schema):
 
 
 class TableMetadataColumnsResponseSchema(Schema):
-    keys = fields.List(fields.String(), description="")
-    longType = fields.String(description="The actual backend long type for the column")
-    name = fields.String(description="The column name")
-    type = fields.String(description="The column type")
+    keys = fields.List(fields.String(), metadata={"description": ""})
+    longType = fields.String(
+        metadata={"description": "The actual backend long type for the column"}
+    )
+    name = fields.String(metadata={"description": "The column name"})
+    type = fields.String(metadata={"description": "The column type"})
     duplicates_constraint = fields.String(required=False)
 
 
 class TableMetadataForeignKeysIndexesResponseSchema(Schema):
     column_names = fields.List(
         fields.String(
-            description="A list of column names that compose the foreign key or index"
+            metadata={
+                "description": "A list of column names that compose the foreign key or "
+                " index"
+            }
         )
     )
-    name = fields.String(description="The name of the foreign key or index")
+    name = fields.String(
+        metadata={"description": "The name of the foreign key or index"}
+    )
     options = fields.Nested(TableMetadataOptionsResponseSchema)
     referred_columns = fields.List(fields.String())
     referred_schema = fields.String()
@@ -541,30 +595,35 @@ class TableMetadataForeignKeysIndexesResponseSchema(Schema):
 
 class TableMetadataPrimaryKeyResponseSchema(Schema):
     column_names = fields.List(
-        fields.String(description="A list of column names that compose the primary key")
+        fields.String(
+            metadata={
+                "description": "A list of column names that compose the primary key"
+            }
+        )
     )
-    name = fields.String(description="The primary key index name")
+    name = fields.String(metadata={"description": "The primary key index name"})
     type = fields.String()
 
 
 class TableMetadataResponseSchema(Schema):
-    name = fields.String(description="The name of the table")
+    name = fields.String(metadata={"description": "The name of the table"})
     columns = fields.List(
         fields.Nested(TableMetadataColumnsResponseSchema),
-        description="A list of columns and their metadata",
+        metadata={"description": "A list of columns and their metadata"},
     )
     foreignKeys = fields.List(
         fields.Nested(TableMetadataForeignKeysIndexesResponseSchema),
-        description="A list of foreign keys and their metadata",
+        metadata={"description": "A list of foreign keys and their metadata"},
     )
     indexes = fields.List(
         fields.Nested(TableMetadataForeignKeysIndexesResponseSchema),
-        description="A list of indexes and their metadata",
+        metadata={"description": "A list of indexes and their metadata"},
     )
     primaryKey = fields.Nested(
-        TableMetadataPrimaryKeyResponseSchema, description="Primary keys metadata"
+        TableMetadataPrimaryKeyResponseSchema,
+        metadata={"description": "Primary keys metadata"},
     )
-    selectStar = fields.String(description="SQL select star")
+    selectStar = fields.String(metadata={"description": "SQL select star"})
 
 
 class TableExtraMetadataResponseSchema(Schema):
@@ -574,21 +633,27 @@ class TableExtraMetadataResponseSchema(Schema):
 
 
 class SelectStarResponseSchema(Schema):
-    result = fields.String(description="SQL select star")
+    result = fields.String(metadata={"description": "SQL select star"})
 
 
 class SchemasResponseSchema(Schema):
-    result = fields.List(fields.String(description="A database schema name"))
+    result = fields.List(
+        fields.String(metadata={"description": "A database schema name"})
+    )
 
 
 class DatabaseTablesResponse(Schema):
-    extra = fields.Dict(description="Extra data used to specify column metadata")
-    type = fields.String(description="table or view")
-    value = fields.String(description="The table or view name")
+    extra = fields.Dict(
+        metadata={"description": "Extra data used to specify column metadata"}
+    )
+    type = fields.String(metadata={"description": "table or view"})
+    value = fields.String(metadata={"description": "The table or view name"})
 
 
 class ValidateSQLRequest(Schema):
-    sql = fields.String(required=True, description="SQL statement to validate")
+    sql = fields.String(
+        required=True, metadata={"description": "SQL statement to validate"}
+    )
     schema = fields.String(required=False, allow_none=True)
     template_params = fields.Dict(required=False, allow_none=True)
 
@@ -614,16 +679,18 @@ class DatabaseRelatedDashboard(Schema):
 
 
 class DatabaseRelatedCharts(Schema):
-    count = fields.Integer(description="Chart count")
+    count = fields.Integer(metadata={"description": "Chart count"})
     result = fields.List(
-        fields.Nested(DatabaseRelatedChart), description="A list of dashboards"
+        fields.Nested(DatabaseRelatedChart),
+        metadata={"description": "A list of dashboards"},
     )
 
 
 class DatabaseRelatedDashboards(Schema):
-    count = fields.Integer(description="Dashboard count")
+    count = fields.Integer(metadata={"description": "Dashboard count"})
     result = fields.List(
-        fields.Nested(DatabaseRelatedDashboard), description="A list of dashboards"
+        fields.Nested(DatabaseRelatedDashboard),
+        metadata={"description": "A list of dashboards"},
     )
 
 
@@ -639,8 +706,8 @@ class DatabaseFunctionNamesResponse(Schema):
 class ImportV1DatabaseExtraSchema(Schema):
     @pre_load
     def fix_schemas_allowed_for_csv_upload(  # pylint: disable=invalid-name
-        self, data: Dict[str, Any], **kwargs: Any
-    ) -> Dict[str, Any]:
+        self, data: dict[str, Any], **kwargs: Any
+    ) -> dict[str, Any]:
         """
         Fixes for ``schemas_allowed_for_csv_upload``.
         """
@@ -676,8 +743,8 @@ class ImportV1DatabaseExtraSchema(Schema):
 class ImportV1DatabaseSchema(Schema):
     @pre_load
     def fix_allow_csv_upload(
-        self, data: Dict[str, Any], **kwargs: Any
-    ) -> Dict[str, Any]:
+        self, data: dict[str, Any], **kwargs: Any
+    ) -> dict[str, Any]:
         """
         Fix for ``allow_csv_upload`` .
         """
@@ -702,11 +769,12 @@ class ImportV1DatabaseSchema(Schema):
     extra = fields.Nested(ImportV1DatabaseExtraSchema)
     uuid = fields.UUID(required=True)
     version = fields.String(required=True)
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
+    ssh_tunnel = fields.Nested(DatabaseSSHTunnel, allow_none=True)
 
     @validates_schema
-    def validate_password(self, data: Dict[str, Any], **kwargs: Any) -> None:
+    def validate_password(self, data: dict[str, Any], **kwargs: Any) -> None:
         """If sqlalchemy_uri has a masked password, password is required"""
         uuid = data["uuid"]
         existing = db.session.query(Database).filter_by(uuid=uuid).first()
@@ -718,6 +786,68 @@ class ImportV1DatabaseSchema(Schema):
         if password == PASSWORD_MASK and data.get("password") is None:
             raise ValidationError("Must provide a password for the database")
 
+    @validates_schema
+    def validate_ssh_tunnel_credentials(
+        self, data: dict[str, Any], **kwargs: Any
+    ) -> None:
+        """If ssh_tunnel has a masked credentials, credentials are required"""
+        uuid = data["uuid"]
+        existing = db.session.query(Database).filter_by(uuid=uuid).first()
+        if existing:
+            return
+
+        # Our DB has a ssh_tunnel in it
+        if ssh_tunnel := data.get("ssh_tunnel"):
+            # Login methods are (only one from these options):
+            # 1. password
+            # 2. private_key + private_key_password
+            # Based on the data passed we determine what info is required.
+            # You cannot mix the credentials from both methods.
+            if not is_feature_enabled("SSH_TUNNELING"):
+                # You are trying to import a Database with SSH Tunnel
+                # But the Feature Flag is not enabled.
+                raise SSHTunnelingNotEnabledError()
+            password = ssh_tunnel.get("password")
+            private_key = ssh_tunnel.get("private_key")
+            private_key_password = ssh_tunnel.get("private_key_password")
+            if password is not None:
+                # Login method #1 (Password)
+                if private_key is not None or private_key_password is not None:
+                    # You cannot have a mix of login methods
+                    raise SSHTunnelInvalidCredentials()
+                if password == PASSWORD_MASK:
+                    raise ValidationError("Must provide a password for the ssh tunnel")
+            if password is None:
+                # If the SSH Tunnel we're importing has no password then it must
+                # have a private_key + private_key_password combination
+                if private_key is None and private_key_password is None:
+                    # We have found nothing related to other credentials
+                    raise SSHTunnelMissingCredentials()
+                # We need to ask for the missing properties of our method # 2
+                # Some times the property is just missing
+                # or there're times where it's masked.
+                # If both are masked, we need to return a list of errors
+                # so the UI ask for both fields at the same time if needed
+                exception_messages: list[str] = []
+                if private_key is None or private_key == PASSWORD_MASK:
+                    # If we get here we need to ask for the private key
+                    exception_messages.append(
+                        "Must provide a private key for the ssh tunnel"
+                    )
+                if (
+                    private_key_password is None
+                    or private_key_password == PASSWORD_MASK
+                ):
+                    # If we get here we need to ask for the private key password
+                    exception_messages.append(
+                        "Must provide a private key password for the ssh tunnel"
+                    )
+                if exception_messages:
+                    # We can ask for just one field or both if masked, if both
+                    # are empty, SSHTunnelMissingCredentials was already raised
+                    raise ValidationError(exception_messages)
+        return
+
 
 class EncryptedField:  # pylint: disable=too-few-public-methods
     """
@@ -733,9 +863,102 @@ class EncryptedDict(EncryptedField, fields.Dict):
     pass
 
 
-def encrypted_field_properties(self, field: Any, **_) -> Dict[str, Any]:  # type: ignore
+def encrypted_field_properties(self, field: Any, **_) -> dict[str, Any]:  # type: ignore
     ret = {}
     if isinstance(field, EncryptedField):
         if self.openapi_version.major > 2:
             ret["x-encrypted-extra"] = True
     return ret
+
+
+class DatabaseSchemaAccessForFileUploadResponse(Schema):
+    schemas = fields.List(
+        fields.String(),
+        metadata={
+            "description": "The list of schemas allowed for the database to upload "
+            "information"
+        },
+    )
+
+
+class DatabaseConnectionSchema(Schema):
+    """
+    Schema with database connection information.
+
+    This is only for admins (who have ``can_create`` on ``Database``).
+    """
+
+    allow_ctas = fields.Boolean(metadata={"description": allow_ctas_description})
+    allow_cvas = fields.Boolean(metadata={"description": allow_cvas_description})
+    allow_dml = fields.Boolean(metadata={"description": allow_dml_description})
+    allow_file_upload = fields.Boolean(
+        metadata={"description": allow_file_upload_description}
+    )
+    allow_run_async = fields.Boolean(
+        metadata={"description": allow_run_async_description}
+    )
+    backend = fields.String(
+        allow_none=True, metadata={"description": "SQLAlchemy engine to use"}
+    )
+    cache_timeout = fields.Integer(
+        metadata={"description": cache_timeout_description}, allow_none=True
+    )
+    configuration_method = fields.String(
+        metadata={"description": configuration_method_description},
+    )
+    database_name = fields.String(
+        metadata={"description": database_name_description},
+        allow_none=True,
+        validate=Length(1, 250),
+    )
+    driver = fields.String(
+        allow_none=True, metadata={"description": "SQLAlchemy driver to use"}
+    )
+    engine_information = fields.Dict(keys=fields.String(), values=fields.Raw())
+    expose_in_sqllab = fields.Boolean(
+        metadata={"description": expose_in_sqllab_description}
+    )
+    extra = fields.String(
+        metadata={"description": extra_description}, validate=extra_validator
+    )
+    force_ctas_schema = fields.String(
+        metadata={"description": force_ctas_schema_description},
+        allow_none=True,
+        validate=Length(0, 250),
+    )
+    id = fields.Integer(metadata={"description": "Database ID (for updates)"})
+    impersonate_user = fields.Boolean(
+        metadata={"description": impersonate_user_description}
+    )
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
+    server_cert = fields.String(
+        metadata={"description": server_cert_description},
+        allow_none=True,
+        validate=server_cert_validator,
+    )
+    uuid = fields.String(required=False)
+    ssh_tunnel = fields.Nested(DatabaseSSHTunnel, allow_none=True)
+    masked_encrypted_extra = fields.String(
+        metadata={"description": encrypted_extra_description},
+        validate=encrypted_extra_validator,
+        allow_none=True,
+    )
+    parameters = fields.Dict(
+        keys=fields.String(),
+        values=fields.Raw(),
+        metadata={"description": "DB-specific parameters for configuration"},
+    )
+    parameters_schema = fields.Dict(
+        keys=fields.String(),
+        values=fields.Raw(),
+        metadata={
+            "description": (
+                "JSONSchema for configuring the database by "
+                "parameters instead of SQLAlchemy URI"
+            ),
+        },
+    )
+    sqlalchemy_uri = fields.String(
+        metadata={"description": sqlalchemy_uri_description},
+        validate=[Length(1, 1024), sqlalchemy_uri_validator],
+    )
