@@ -16,7 +16,7 @@
 # under the License.
 import json
 import re
-from typing import Any, Dict
+from typing import Any
 
 from flask_babel import lazy_gettext as _
 from marshmallow import fields, pre_load, Schema, ValidationError
@@ -34,29 +34,29 @@ def validate_python_date_format(value: str) -> None:
         r"""
         ^(
             epoch_s|epoch_ms|
-            (?P<date>%Y(-%m(-%d)?)?)([\sT](?P<time>%H(:%M(:%S(\.%f)?)?)?))?
+            (?P<date>%Y([-/]%m([-/]%d)?)?)([\sT](?P<time>%H(:%M(:%S(\.%f)?)?)?))?
         )$
         """,
         re.VERBOSE,
     )
     match = regex.match(value or "")
     if not match:
-        raise ValidationError(_("Invalid date/timestamp format"))
+        raise ValidationError([_("Invalid date/timestamp format")])
 
 
 class DatasetColumnsPutSchema(Schema):
-    id = fields.Integer()
+    id = fields.Integer(required=False)
     column_name = fields.String(required=True, validate=Length(1, 255))
     type = fields.String(allow_none=True)
     advanced_data_type = fields.String(allow_none=True, validate=Length(1, 255))
-    verbose_name = fields.String(allow_none=True, Length=(1, 1024))
+    verbose_name = fields.String(allow_none=True, metadata={Length: (1, 1024)})
     description = fields.String(allow_none=True)
     expression = fields.String(allow_none=True)
     extra = fields.String(allow_none=True)
     filterable = fields.Boolean()
     groupby = fields.Boolean()
-    is_active = fields.Boolean()
-    is_dttm = fields.Boolean(default=False)
+    is_active = fields.Boolean(allow_none=True)
+    is_dttm = fields.Boolean(allow_none=True, dump_default=False)
     python_date_format = fields.String(
         allow_none=True, validate=[Length(1, 255), validate_python_date_format]
     )
@@ -71,19 +71,21 @@ class DatasetMetricsPutSchema(Schema):
     metric_name = fields.String(required=True, validate=Length(1, 255))
     metric_type = fields.String(allow_none=True, validate=Length(1, 32))
     d3format = fields.String(allow_none=True, validate=Length(1, 128))
-    verbose_name = fields.String(allow_none=True, Length=(1, 1024))
+    currency = fields.String(allow_none=True, required=False, validate=Length(1, 128))
+    verbose_name = fields.String(allow_none=True, metadata={Length: (1, 1024)})
     warning_text = fields.String(allow_none=True)
     uuid = fields.UUID(allow_none=True)
 
 
 class DatasetPostSchema(Schema):
     database = fields.Integer(required=True)
-    schema = fields.String(validate=Length(0, 250))
+    schema = fields.String(allow_none=True, validate=Length(0, 250))
     table_name = fields.String(required=True, allow_none=False, validate=Length(1, 250))
     sql = fields.String(allow_none=True)
     owners = fields.List(fields.Integer())
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
+    normalize_columns = fields.Boolean(load_default=False)
 
 
 class DatasetPutSchema(Schema):
@@ -95,6 +97,7 @@ class DatasetPutSchema(Schema):
     schema = fields.String(allow_none=True, validate=Length(0, 255))
     description = fields.String(allow_none=True)
     main_dttm_col = fields.String(allow_none=True)
+    normalize_columns = fields.Boolean(allow_none=True, dump_default=False)
     offset = fields.Integer(allow_none=True)
     default_endpoint = fields.String(allow_none=True)
     cache_timeout = fields.Integer(allow_none=True)
@@ -104,7 +107,7 @@ class DatasetPutSchema(Schema):
     columns = fields.List(fields.Nested(DatasetColumnsPutSchema))
     metrics = fields.List(fields.Nested(DatasetMetricsPutSchema))
     extra = fields.String(allow_none=True)
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
 
 
@@ -127,16 +130,18 @@ class DatasetRelatedDashboard(Schema):
 
 
 class DatasetRelatedCharts(Schema):
-    count = fields.Integer(description="Chart count")
+    count = fields.Integer(metadata={"description": "Chart count"})
     result = fields.List(
-        fields.Nested(DatasetRelatedChart), description="A list of dashboards"
+        fields.Nested(DatasetRelatedChart),
+        metadata={"description": "A list of dashboards"},
     )
 
 
 class DatasetRelatedDashboards(Schema):
-    count = fields.Integer(description="Dashboard count")
+    count = fields.Integer(metadata={"description": "Dashboard count"})
     result = fields.List(
-        fields.Nested(DatasetRelatedDashboard), description="A list of dashboards"
+        fields.Nested(DatasetRelatedDashboard),
+        metadata={"description": "A list of dashboards"},
     )
 
 
@@ -148,7 +153,7 @@ class DatasetRelatedObjectsResponse(Schema):
 class ImportV1ColumnSchema(Schema):
     # pylint: disable=no-self-use, unused-argument
     @pre_load
-    def fix_extra(self, data: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
+    def fix_extra(self, data: dict[str, Any], **kwargs: Any) -> dict[str, Any]:
         """
         Fix for extra initially being exported as a string.
         """
@@ -160,8 +165,8 @@ class ImportV1ColumnSchema(Schema):
     column_name = fields.String(required=True)
     extra = fields.Dict(allow_none=True)
     verbose_name = fields.String(allow_none=True)
-    is_dttm = fields.Boolean(default=False, allow_none=True)
-    is_active = fields.Boolean(default=True, allow_none=True)
+    is_dttm = fields.Boolean(dump_default=False, allow_none=True)
+    is_active = fields.Boolean(dump_default=True, allow_none=True)
     type = fields.String(allow_none=True)
     advanced_data_type = fields.String(allow_none=True)
     groupby = fields.Boolean()
@@ -174,7 +179,7 @@ class ImportV1ColumnSchema(Schema):
 class ImportV1MetricSchema(Schema):
     # pylint: disable=no-self-use, unused-argument
     @pre_load
-    def fix_extra(self, data: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
+    def fix_extra(self, data: dict[str, Any], **kwargs: Any) -> dict[str, Any]:
         """
         Fix for extra initially being exported as a string.
         """
@@ -189,6 +194,7 @@ class ImportV1MetricSchema(Schema):
     expression = fields.String(required=True)
     description = fields.String(allow_none=True)
     d3format = fields.String(allow_none=True)
+    currency = fields.String(allow_none=True, required=False)
     extra = fields.Dict(allow_none=True)
     warning_text = fields.String(allow_none=True)
 
@@ -196,12 +202,16 @@ class ImportV1MetricSchema(Schema):
 class ImportV1DatasetSchema(Schema):
     # pylint: disable=no-self-use, unused-argument
     @pre_load
-    def fix_extra(self, data: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
+    def fix_extra(self, data: dict[str, Any], **kwargs: Any) -> dict[str, Any]:
         """
         Fix for extra initially being exported as a string.
         """
         if isinstance(data.get("extra"), str):
-            data["extra"] = json.loads(data["extra"])
+            try:
+                extra = data["extra"]
+                data["extra"] = json.loads(extra) if extra.strip() else None
+            except ValueError:
+                data["extra"] = None
 
         return data
 
@@ -224,19 +234,25 @@ class ImportV1DatasetSchema(Schema):
     version = fields.String(required=True)
     database_uuid = fields.UUID(required=True)
     data = fields.URL()
-    is_managed_externally = fields.Boolean(allow_none=True, default=False)
+    is_managed_externally = fields.Boolean(allow_none=True, dump_default=False)
     external_url = fields.String(allow_none=True)
+    normalize_columns = fields.Boolean(load_default=False)
 
 
 class GetOrCreateDatasetSchema(Schema):
-    table_name = fields.String(required=True, description="Name of table")
+    table_name = fields.String(required=True, metadata={"description": "Name of table"})
     database_id = fields.Integer(
-        required=True, description="ID of database table belongs to"
+        required=True, metadata={"description": "ID of database table belongs to"}
     )
     schema = fields.String(
-        description="The schema the table belongs to", allow_none=True
+        allow_none=True,
+        validate=Length(0, 250),
+        metadata={"description": "The schema the table belongs to"},
     )
-    template_params = fields.String(description="Template params for the table")
+    template_params = fields.String(
+        metadata={"description": "Template params for the table"}
+    )
+    normalize_columns = fields.Boolean(load_default=False)
 
 
 class DatasetSchema(SQLAlchemyAutoSchema):
@@ -248,3 +264,43 @@ class DatasetSchema(SQLAlchemyAutoSchema):
         model = Dataset
         load_instance = True
         include_relationships = True
+
+
+class DatasetCacheWarmUpRequestSchema(Schema):
+    db_name = fields.String(
+        required=True,
+        metadata={"description": "The name of the database where the table is located"},
+    )
+    table_name = fields.String(
+        required=True,
+        metadata={"description": "The name of the table to warm up cache for"},
+    )
+    dashboard_id = fields.Integer(
+        metadata={
+            "description": "The ID of the dashboard to get filters for when warming cache"
+        }
+    )
+    extra_filters = fields.String(
+        metadata={"description": "Extra filters to apply when warming up cache"}
+    )
+
+
+class DatasetCacheWarmUpResponseSingleSchema(Schema):
+    chart_id = fields.Integer(
+        metadata={"description": "The ID of the chart the status belongs to"}
+    )
+    viz_error = fields.String(
+        metadata={"description": "Error that occurred when warming cache for chart"}
+    )
+    viz_status = fields.String(
+        metadata={"description": "Status of the underlying query for the viz"}
+    )
+
+
+class DatasetCacheWarmUpResponseSchema(Schema):
+    result = fields.List(
+        fields.Nested(DatasetCacheWarmUpResponseSingleSchema),
+        metadata={
+            "description": "A list of each chart's warmup status and errors if any"
+        },
+    )
