@@ -18,30 +18,50 @@ import json
 import re
 import urllib
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Pattern, Tuple, Type, TYPE_CHECKING
+from re import Pattern
+from typing import Any, Optional, TYPE_CHECKING
 
 import pandas as pd
 from apispec import APISpec
 from apispec.ext.marshmallow import MarshmallowPlugin
+from deprecation import deprecated
 from flask_babel import gettext as __
 from marshmallow import fields, Schema
 from marshmallow.exceptions import ValidationError
 from sqlalchemy import column, types
 from sqlalchemy.engine.base import Engine
+from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.sql import sqltypes
 from typing_extensions import TypedDict
 
 from superset import sql_parse
-from superset.constants import PASSWORD_MASK
+from superset.constants import PASSWORD_MASK, TimeGrain
 from superset.databases.schemas import encrypted_field_properties, EncryptedString
 from superset.databases.utils import make_url_safe
 from superset.db_engine_specs.base import BaseEngineSpec, BasicPropertiesType
 from superset.db_engine_specs.exceptions import SupersetDBAPIConnectionError
 from superset.errors import SupersetError, SupersetErrorType
+from superset.exceptions import SupersetException
 from superset.sql_parse import Table
+from superset.superset_typing import ResultSetColumnType
 from superset.utils import core as utils
 from superset.utils.hashing import md5_sha_from_str
 
+try:
+    from google.cloud import bigquery
+    from google.oauth2 import service_account
+
+    dependencies_installed = True
+except ModuleNotFoundError:
+    dependencies_installed = False
+
+try:
+    import pandas_gbq
+
+    can_upload = True
+except ModuleNotFoundError:
+    can_upload = False
+
 if TYPE_CHECKING:
     from superset.models.core import Database  # pragma: no cover
 
@@ -75,17 +95,17 @@ ma_plugin = MarshmallowPlugin()
 class BigQueryParametersSchema(Schema):
     credentials_info = EncryptedString(
         required=False,
-        description="Contents of BigQuery JSON credentials.",
+        metadata={"description": "Contents of BigQuery JSON credentials."},
     )
     query = fields.Dict(required=False)
 
 
 class BigQueryParametersType(TypedDict):
-    credentials_info: Dict[str, Any]
-    query: Dict[str, Any]
+    credentials_info: dict[str, Any]
+    query: dict[str, Any]
 
 
-class BigQueryEngineSpec(BaseEngineSpec):
+class BigQueryEngineSpec(BaseEngineSpec):  # pylint: disable=too-many-public-methods
     """Engine spec for Google's BigQuery
 
     As contributed by @mxmzdlv on issue #945"""
@@ -105,6 +125,8 @@ class BigQueryEngineSpec(BaseEngineSpec):
 
     allows_hidden_cc_in_orderby = True
 
+    supports_catalog = True
+
     """
     https://www.python.org/dev/peps/pep-0249/#arraysize
     raw_connections bypass the sqlalchemy-bigquery query execution context and deal with
@@ -126,34 +148,34 @@ class BigQueryEngineSpec(BaseEngineSpec):
 
     _time_grain_expressions = {
         None: "{col}",
-        "PT1S": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.SECOND: "CAST(TIMESTAMP_SECONDS("
         "UNIX_SECONDS(CAST({col} AS TIMESTAMP))"
         ") AS {type})",
-        "PT1M": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.MINUTE: "CAST(TIMESTAMP_SECONDS("
         "60 * DIV(UNIX_SECONDS(CAST({col} AS TIMESTAMP)), 60)"
         ") AS {type})",
-        "PT5M": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.FIVE_MINUTES: "CAST(TIMESTAMP_SECONDS("
         "5*60 * DIV(UNIX_SECONDS(CAST({col} AS TIMESTAMP)), 5*60)"
         ") AS {type})",
-        "PT10M": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.TEN_MINUTES: "CAST(TIMESTAMP_SECONDS("
         "10*60 * DIV(UNIX_SECONDS(CAST({col} AS TIMESTAMP)), 10*60)"
         ") AS {type})",
-        "PT15M": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.FIFTEEN_MINUTES: "CAST(TIMESTAMP_SECONDS("
         "15*60 * DIV(UNIX_SECONDS(CAST({col} AS TIMESTAMP)), 15*60)"
         ") AS {type})",
-        "PT30M": "CAST(TIMESTAMP_SECONDS("
+        TimeGrain.THIRTY_MINUTES: "CAST(TIMESTAMP_SECONDS("
         "30*60 * DIV(UNIX_SECONDS(CAST({col} AS TIMESTAMP)), 30*60)"
         ") AS {type})",
-        "PT1H": "{func}({col}, HOUR)",
-        "P1D": "{func}({col}, DAY)",
-        "P1W": "{func}({col}, WEEK)",
-        "1969-12-29T00:00:00Z/P1W": "{func}({col}, ISOWEEK)",
-        "P1M": "{func}({col}, MONTH)",
-        "P3M": "{func}({col}, QUARTER)",
-        "P1Y": "{func}({col}, YEAR)",
+        TimeGrain.HOUR: "{func}({col}, HOUR)",
+        TimeGrain.DAY: "{func}({col}, DAY)",
+        TimeGrain.WEEK: "{func}({col}, WEEK)",
+        TimeGrain.WEEK_STARTING_MONDAY: "{func}({col}, ISOWEEK)",
+        TimeGrain.MONTH: "{func}({col}, MONTH)",
+        TimeGrain.QUARTER: "{func}({col}, QUARTER)",
+        TimeGrain.YEAR: "{func}({col}, YEAR)",
     }
 
-    custom_errors: Dict[Pattern[str], Tuple[str, SupersetErrorType, Dict[str, Any]]] = {
+    custom_errors: dict[Pattern[str], tuple[str, SupersetErrorType, dict[str, Any]]] = {
         CONNECTION_DATABASE_PERMISSIONS_REGEX: (
             __(
                 "Unable to connect. Verify that the following roles are set "
@@ -199,7 +221,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
 
     @classmethod
     def convert_dttm(
-        cls, target_type: str, dttm: datetime, db_extra: Optional[Dict[str, Any]] = None
+        cls, target_type: str, dttm: datetime, db_extra: Optional[dict[str, Any]] = None
     ) -> Optional[str]:
         sqla_type = cls.get_sqla_column_type(target_type)
         if isinstance(sqla_type, types.Date):
@@ -215,7 +237,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
     @classmethod
     def fetch_data(
         cls, cursor: Any, limit: Optional[int] = None
-    ) -> List[Tuple[Any, ...]]:
+    ) -> list[tuple[Any, ...]]:
         data = super().fetch_data(cursor, limit)
         # Support type BigQuery Row, introduced here PR #4071
         # google.cloud.bigquery.table.Row
@@ -259,7 +281,8 @@ class BigQueryEngineSpec(BaseEngineSpec):
         return "_" + md5_sha_from_str(label)
 
     @classmethod
-    def normalize_indexes(cls, indexes: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+    @deprecated(deprecated_in="3.0")
+    def normalize_indexes(cls, indexes: list[dict[str, Any]]) -> list[dict[str, Any]]:
         """
         Normalizes indexes for more consistency across db engines
 
@@ -277,10 +300,30 @@ class BigQueryEngineSpec(BaseEngineSpec):
                 normalized_idxs.append(ix)
         return normalized_idxs
 
+    @classmethod
+    def get_indexes(
+        cls,
+        database: "Database",
+        inspector: Inspector,
+        table_name: str,
+        schema: Optional[str],
+    ) -> list[dict[str, Any]]:
+        """
+        Get the indexes associated with the specified schema/table.
+
+        :param database: The database to inspect
+        :param inspector: The SQLAlchemy inspector
+        :param table_name: The table to inspect
+        :param schema: The schema to inspect
+        :returns: The indexes
+        """
+
+        return cls.normalize_indexes(inspector.get_indexes(table_name, schema))
+
     @classmethod
     def extra_table_metadata(
         cls, database: "Database", table_name: str, schema_name: Optional[str]
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         indexes = database.get_indexes(table_name, schema_name)
         if not indexes:
             return {}
@@ -313,7 +356,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         database: "Database",
         table: Table,
         df: pd.DataFrame,
-        to_sql_kwargs: Dict[str, Any],
+        to_sql_kwargs: dict[str, Any],
     ) -> None:
         """
         Upload data from a Pandas DataFrame to a database.
@@ -327,20 +370,13 @@ class BigQueryEngineSpec(BaseEngineSpec):
         :param df: The dataframe with data to be uploaded
         :param to_sql_kwargs: The kwargs to be passed to pandas.DataFrame.to_sql` method
         """
-
-        try:
-            # pylint: disable=import-outside-toplevel
-            import pandas_gbq
-            from google.oauth2 import service_account
-        except ImportError as ex:
-            raise Exception(
-                "Could not import libraries `pandas_gbq` or `google.oauth2`, which are "
-                "required to be installed in your environment in order "
-                "to upload data to BigQuery"
-            ) from ex
+        if not can_upload:
+            raise SupersetException(
+                "Could not import libraries needed to upload data to BigQuery."
+            )
 
         if not table.schema:
-            raise Exception("The table schema must be defined")
+            raise SupersetException("The table schema must be defined")
 
         to_gbq_kwargs = {}
         with cls.get_engine(database) as engine:
@@ -350,9 +386,8 @@ class BigQueryEngineSpec(BaseEngineSpec):
             }
 
         # Add credentials if they are set on the SQLAlchemy dialect.
-        creds = engine.dialect.credentials_info
 
-        if creds:
+        if creds := engine.dialect.credentials_info:
             to_gbq_kwargs[
                 "credentials"
             ] = service_account.Credentials.from_service_account_info(creds)
@@ -366,6 +401,21 @@ class BigQueryEngineSpec(BaseEngineSpec):
 
         pandas_gbq.to_gbq(df, **to_gbq_kwargs)
 
+    @classmethod
+    def _get_client(cls, engine: Engine) -> Any:
+        """
+        Return the BigQuery client associated with an engine.
+        """
+        if not dependencies_installed:
+            raise SupersetException(
+                "Could not import libraries needed to connect to BigQuery."
+            )
+
+        credentials = service_account.Credentials.from_service_account_info(
+            engine.dialect.credentials_info
+        )
+        return bigquery.Client(credentials=credentials)
+
     @classmethod
     def estimate_query_cost(
         cls,
@@ -373,7 +423,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         schema: str,
         sql: str,
         source: Optional[utils.QuerySource] = None,
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         """
         Estimate the cost of a multiple statement SQL query.
 
@@ -384,7 +434,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         """
         extra = database.get_extra() or {}
         if not cls.get_allow_cost_estimate(extra):
-            raise Exception("Database does not support cost estimation")
+            raise SupersetException("Database does not support cost estimation")
 
         parsed_query = sql_parse.ParsedQuery(sql)
         statements = parsed_query.get_statements()
@@ -396,34 +446,36 @@ class BigQueryEngineSpec(BaseEngineSpec):
         return costs
 
     @classmethod
-    def get_allow_cost_estimate(cls, extra: Dict[str, Any]) -> bool:
+    def get_catalog_names(
+        cls,
+        database: "Database",
+        inspector: Inspector,
+    ) -> list[str]:
+        """
+        Get all catalogs.
+
+        In BigQuery, a catalog is called a "project".
+        """
+        engine: Engine
+        with database.get_sqla_engine_with_context() as engine:
+            client = cls._get_client(engine)
+            projects = client.list_projects()
+
+        return sorted(project.project_id for project in projects)
+
+    @classmethod
+    def get_allow_cost_estimate(cls, extra: dict[str, Any]) -> bool:
         return True
 
     @classmethod
-    def estimate_statement_cost(cls, statement: str, cursor: Any) -> Dict[str, Any]:
-        try:
-            # pylint: disable=import-outside-toplevel
-            # It's the only way to perfom a dry-run estimate cost
-            from google.cloud import bigquery
-            from google.oauth2 import service_account
-        except ImportError as ex:
-            raise Exception(
-                "Could not import libraries `pygibquery` or `google.oauth2`, which are "
-                "required to be installed in your environment in order "
-                "to upload data to BigQuery"
-            ) from ex
-
+    def estimate_statement_cost(cls, statement: str, cursor: Any) -> dict[str, Any]:
         with cls.get_engine(cursor) as engine:
-            creds = engine.dialect.credentials_info
-
-        creds = service_account.Credentials.from_service_account_info(creds)
-        client = bigquery.Client(credentials=creds)
-        job_config = bigquery.QueryJobConfig(dry_run=True)
-
-        query_job = client.query(
-            statement,
-            job_config=job_config,
-        )  # Make an API request.
+            client = cls._get_client(engine)
+            job_config = bigquery.QueryJobConfig(dry_run=True)
+            query_job = client.query(
+                statement,
+                job_config=job_config,
+            )  # Make an API request.
 
         # Format Bytes.
         # TODO: Humanize in case more db engine specs need to be added,
@@ -453,15 +505,15 @@ class BigQueryEngineSpec(BaseEngineSpec):
 
     @classmethod
     def query_cost_formatter(
-        cls, raw_cost: List[Dict[str, Any]]
-    ) -> List[Dict[str, str]]:
+        cls, raw_cost: list[dict[str, Any]]
+    ) -> list[dict[str, str]]:
         return [{k: str(v) for k, v in row.items()} for row in raw_cost]
 
     @classmethod
     def build_sqlalchemy_uri(
         cls,
         parameters: BigQueryParametersType,
-        encrypted_extra: Optional[Dict[str, Any]] = None,
+        encrypted_extra: Optional[dict[str, Any]] = None,
     ) -> str:
         query = parameters.get("query", {})
         query_params = urllib.parse.urlencode(query)
@@ -483,7 +535,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
     def get_parameters_from_uri(
         cls,
         uri: str,
-        encrypted_extra: Optional[Dict[str, Any]] = None,
+        encrypted_extra: Optional[dict[str, Any]] = None,
     ) -> Any:
         value = make_url_safe(uri)
 
@@ -542,7 +594,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         return json.dumps(new_config)
 
     @classmethod
-    def get_dbapi_exception_mapping(cls) -> Dict[Type[Exception], Type[Exception]]:
+    def get_dbapi_exception_mapping(cls) -> dict[type[Exception], type[Exception]]:
         # pylint: disable=import-outside-toplevel
         from google.auth.exceptions import DefaultCredentialsError
 
@@ -552,7 +604,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
     def validate_parameters(
         cls,
         properties: BasicPropertiesType,  # pylint: disable=unused-argument
-    ) -> List[SupersetError]:
+    ) -> list[SupersetError]:
         return []
 
     @classmethod
@@ -586,7 +638,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         show_cols: bool = False,
         indent: bool = True,
         latest_partition: bool = True,
-        cols: Optional[List[Dict[str, Any]]] = None,
+        cols: Optional[list[ResultSetColumnType]] = None,
     ) -> str:
         """
         Remove array structures from `SELECT *`.
@@ -627,13 +679,15 @@ class BigQueryEngineSpec(BaseEngineSpec):
             # For arrays of structs, remove the child columns, otherwise the query
             # will fail.
             array_prefixes = {
-                col["name"] for col in cols if isinstance(col["type"], sqltypes.ARRAY)
+                col["column_name"]
+                for col in cols
+                if isinstance(col["type"], sqltypes.ARRAY)
             }
             cols = [
                 col
                 for col in cols
-                if "." not in col["name"]
-                or col["name"].split(".")[0] not in array_prefixes
+                if "." not in col["column_name"]
+                or col["column_name"].split(".")[0] not in array_prefixes
             ]
 
         return super().select_star(
@@ -649,7 +703,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
         )
 
     @classmethod
-    def _get_fields(cls, cols: List[Dict[str, Any]]) -> List[Any]:
+    def _get_fields(cls, cols: list[ResultSetColumnType]) -> list[Any]:
         """
         Label columns using their fully qualified name.
 
@@ -674,7 +728,10 @@ class BigQueryEngineSpec(BaseEngineSpec):
         the columns using their fully qualified name, so we end up with "author",
         "author__name" and "author__email", respectively.
         """
-        return [column(c["name"]).label(c["name"].replace(".", "__")) for c in cols]
+        return [
+            column(c["column_name"]).label(c["column_name"].replace(".", "__"))
+            for c in cols
+        ]
 
     @classmethod
     def parse_error_exception(cls, exception: Exception) -> Exception:
