@@ -29,7 +29,7 @@ down_revision = "ad07e4fdbaba"
 import json
 import os
 from datetime import datetime
-from typing import List, Optional, Set, Type, Union
+from typing import Optional, Union
 from uuid import uuid4
 
 import sqlalchemy as sa
@@ -86,7 +86,7 @@ class AuxiliaryColumnsMixin(UUIDMixin):
 
 
 def insert_from_select(
-    target: Union[str, sa.Table, Type[Base]], source: sa.sql.expression.Select
+    target: Union[str, sa.Table, type[Base]], source: sa.sql.expression.Select
 ) -> None:
     """
     Execute INSERT FROM SELECT to copy data from a SELECT query to the target table.
@@ -103,7 +103,6 @@ def insert_from_select(
 
 
 class Database(Base):
-
     __tablename__ = "dbs"
     __table_args__ = (UniqueConstraint("database_name"),)
 
@@ -118,7 +117,6 @@ class Database(Base):
 
 
 class TableColumn(AuxiliaryColumnsMixin, Base):
-
     __tablename__ = "table_columns"
     __table_args__ = (UniqueConstraint("table_id", "column_name"),)
 
@@ -138,7 +136,6 @@ class TableColumn(AuxiliaryColumnsMixin, Base):
 
 
 class SqlMetric(AuxiliaryColumnsMixin, Base):
-
     __tablename__ = "sql_metrics"
     __table_args__ = (UniqueConstraint("table_id", "metric_name"),)
 
@@ -164,7 +161,6 @@ sqlatable_user_table = sa.Table(
 
 
 class SqlaTable(AuxiliaryColumnsMixin, Base):
-
     __tablename__ = "tables"
     __table_args__ = (UniqueConstraint("database_id", "schema", "table_name"),)
 
@@ -213,7 +209,6 @@ dataset_user_association_table = sa.Table(
 
 
 class NewColumn(AuxiliaryColumnsMixin, Base):
-
     __tablename__ = "sl_columns"
 
     id = sa.Column(sa.Integer, primary_key=True)
@@ -243,7 +238,6 @@ class NewColumn(AuxiliaryColumnsMixin, Base):
 
 
 class NewTable(AuxiliaryColumnsMixin, Base):
-
     __tablename__ = "sl_tables"
 
     id = sa.Column(sa.Integer, primary_key=True)
@@ -264,7 +258,6 @@ class NewTable(AuxiliaryColumnsMixin, Base):
 
 
 class NewDataset(Base, AuxiliaryColumnsMixin):
-
     __tablename__ = "sl_datasets"
 
     id = sa.Column(sa.Integer, primary_key=True)
@@ -281,8 +274,8 @@ def find_tables(
     session: Session,
     database_id: int,
     default_schema: Optional[str],
-    tables: Set[Table],
-) -> List[int]:
+    tables: set[Table],
+) -> list[int]:
     """
     Look for NewTable's of from a specific database
     """
@@ -636,7 +629,6 @@ def postprocess_columns(session: Session) -> None:
         return
 
     def get_joined_tables(offset, limit):
-
         # Import aliased from sqlalchemy
         from sqlalchemy.orm import aliased
 
@@ -788,7 +780,7 @@ def postprocess_columns(session: Session) -> None:
                 updates["external_url"] = external_url
 
             # update extra json
-            for (key, val) in (
+            for key, val in (
                 {
                     "verbose_name": verbose_name,
                     "python_date_format": python_date_format,
