@@ -18,11 +18,10 @@ from __future__ import annotations
 
 import json
 import logging
-from typing import Any, Dict, Optional, Type, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING
 from urllib import parse
 
 import sqlalchemy as sqla
-from flask import current_app
 from flask_appbuilder import Model
 from flask_appbuilder.models.decorators import renders
 from markupsafe import escape, Markup
@@ -59,8 +58,8 @@ slice_user = Table(
     "slice_user",
     metadata,
     Column("id", Integer, primary_key=True),
-    Column("user_id", Integer, ForeignKey("ab_user.id")),
-    Column("slice_id", Integer, ForeignKey("slices.id")),
+    Column("user_id", Integer, ForeignKey("ab_user.id", ondelete="CASCADE")),
+    Column("slice_id", Integer, ForeignKey("slices.id", ondelete="CASCADE")),
 )
 logger = logging.getLogger(__name__)
 
@@ -70,7 +69,7 @@ class Slice(  # pylint: disable=too-many-public-methods
 ):
     """A slice is essentially a report or a view on data"""
 
-    query_context_factory: Optional[QueryContextFactory] = None
+    query_context_factory: QueryContextFactory | None = None
 
     __tablename__ = "slices"
     id = Column(Integer, primary_key=True)
@@ -96,10 +95,23 @@ class Slice(  # pylint: disable=too-many-public-methods
     last_saved_by = relationship(
         security_manager.user_model, foreign_keys=[last_saved_by_fk]
     )
-    owners = relationship(security_manager.user_model, secondary=slice_user)
+    owners = relationship(
+        security_manager.user_model,
+        secondary=slice_user,
+        passive_deletes=True,
+    )
+    tags = relationship(
+        "Tag",
+        secondary="tagged_object",
+        overlaps="objects,tag,tags",
+        primaryjoin="and_(Slice.id == TaggedObject.object_id)",
+        secondaryjoin="and_(TaggedObject.tag_id == Tag.id, "
+        "TaggedObject.object_type == 'chart')",
+    )
     table = relationship(
         "SqlaTable",
         foreign_keys=[datasource_id],
+        overlaps="table",
         primaryjoin="and_(Slice.datasource_id == SqlaTable.id, "
         "Slice.datasource_type == 'table')",
         remote_side="SqlaTable.id",
@@ -127,17 +139,17 @@ class Slice(  # pylint: disable=too-many-public-methods
         return self.slice_name or str(self.id)
 
     @property
-    def cls_model(self) -> Type["BaseDatasource"]:
+    def cls_model(self) -> type[BaseDatasource]:
         # pylint: disable=import-outside-toplevel
-        from superset.datasource.dao import DatasourceDAO
+        from superset.daos.datasource import DatasourceDAO
 
         return DatasourceDAO.sources[self.datasource_type]
 
     @property
-    def datasource(self) -> Optional["BaseDatasource"]:
+    def datasource(self) -> BaseDatasource | None:
         return self.get_datasource
 
-    def clone(self) -> "Slice":
+    def clone(self) -> Slice:
         return Slice(
             slice_name=self.slice_name,
             datasource_id=self.datasource_id,
@@ -151,7 +163,7 @@ class Slice(  # pylint: disable=too-many-public-methods
 
     # pylint: disable=using-constant-test
     @datasource.getter  # type: ignore
-    def get_datasource(self) -> Optional["BaseDatasource"]:
+    def get_datasource(self) -> BaseDatasource | None:
         return (
             db.session.query(self.cls_model)
             .filter_by(id=self.datasource_id)
@@ -159,20 +171,20 @@ class Slice(  # pylint: disable=too-many-public-methods
         )
 
     @renders("datasource_name")
-    def datasource_link(self) -> Optional[Markup]:
+    def datasource_link(self) -> Markup | None:
         # pylint: disable=no-member
         datasource = self.datasource
         return datasource.link if datasource else None
 
     @renders("datasource_url")
-    def datasource_url(self) -> Optional[str]:
+    def datasource_url(self) -> str | None:
         # pylint: disable=no-member
         if self.table:
             return self.table.explore_url
         datasource = self.datasource
         return datasource.explore_url if datasource else None
 
-    def datasource_name_text(self) -> Optional[str]:
+    def datasource_name_text(self) -> str | None:
         # pylint: disable=no-member
         if self.table:
             if self.table.schema:
@@ -185,7 +197,7 @@ class Slice(  # pylint: disable=too-many-public-methods
         return None
 
     @property
-    def datasource_edit_url(self) -> Optional[str]:
+    def datasource_edit_url(self) -> str | None:
         # pylint: disable=no-member
         datasource = self.datasource
         return datasource.url if datasource else None
@@ -193,7 +205,7 @@ class Slice(  # pylint: disable=too-many-public-methods
     # pylint: enable=using-constant-test
 
     @property
-    def viz(self) -> Optional[BaseViz]:
+    def viz(self) -> BaseViz | None:
         form_data = json.loads(self.params)
         viz_class = viz_types.get(self.viz_type)
         datasource = self.datasource
@@ -206,9 +218,9 @@ class Slice(  # pylint: disable=too-many-public-methods
         return utils.markdown(self.description)
 
     @property
-    def data(self) -> Dict[str, Any]:
+    def data(self) -> dict[str, Any]:
         """Data used to render slice in templates"""
-        data: Dict[str, Any] = {}
+        data: dict[str, Any] = {}
         self.token = ""
         try:
             viz = self.viz
@@ -254,8 +266,8 @@ class Slice(  # pylint: disable=too-many-public-methods
         return json.dumps(self.data)
 
     @property
-    def form_data(self) -> Dict[str, Any]:
-        form_data: Dict[str, Any] = {}
+    def form_data(self) -> dict[str, Any]:
+        form_data: dict[str, Any] = {}
         try:
             form_data = json.loads(self.params)
         except Exception as ex:  # pylint: disable=broad-except
@@ -265,7 +277,7 @@ class Slice(  # pylint: disable=too-many-public-methods
             {
                 "slice_id": self.id,
                 "viz_type": self.viz_type,
-                "datasource": "{}__{}".format(self.datasource_id, self.datasource_type),
+                "datasource": f"{self.datasource_id}__{self.datasource_type}",
             }
         )
 
@@ -274,7 +286,7 @@ class Slice(  # pylint: disable=too-many-public-methods
         update_time_range(form_data)
         return form_data
 
-    def get_query_context(self) -> Optional[QueryContext]:
+    def get_query_context(self) -> QueryContext | None:
         if self.query_context:
             try:
                 return self.get_query_context_factory().create(
@@ -288,13 +300,13 @@ class Slice(  # pylint: disable=too-many-public-methods
     def get_explore_url(
         self,
         base_url: str = "/explore",
-        overrides: Optional[Dict[str, Any]] = None,
+        overrides: dict[str, Any] | None = None,
     ) -> str:
         return self.build_explore_url(self.id, base_url, overrides)
 
     @staticmethod
     def build_explore_url(
-        id_: int, base_url: str = "/explore", overrides: Optional[Dict[str, Any]] = None
+        id_: int, base_url: str = "/explore", overrides: dict[str, Any] | None = None
     ) -> str:
         overrides = overrides or {}
         form_data = {"slice_id": id_}
@@ -325,15 +337,6 @@ class Slice(  # pylint: disable=too-many-public-methods
         name = escape(self.chart)
         return Markup(f'<a href="{self.url}">{name}</a>')
 
-    @property
-    def changed_by_url(self) -> str:
-        if (
-            not self.changed_by
-            or not current_app.config["ENABLE_BROAD_ACTIVITY_ACCESS"]
-        ):
-            return ""
-        return f"/superset/profile/{self.changed_by.username}"
-
     @property
     def icons(self) -> str:
         return f"""
@@ -365,8 +368,7 @@ class Slice(  # pylint: disable=too-many-public-methods
 
 def set_related_perm(_mapper: Mapper, _connection: Connection, target: Slice) -> None:
     src_class = target.cls_model
-    id_ = target.datasource_id
-    if id_:
+    if id_ := target.datasource_id:
         ds = db.session.query(src_class).filter_by(id=int(id_)).first()
         if ds:
             target.perm = ds.perm
