@@ -15,11 +15,13 @@
 # specific language governing permissions and limitations
 # under the License.
 """A collection of ORM sqlalchemy models for SQL Lab"""
+import builtins
 import inspect
 import logging
 import re
+from collections.abc import Hashable
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Type, TYPE_CHECKING
+from typing import Any, Optional, TYPE_CHECKING
 
 import simplejson as json
 import sqlalchemy as sqla
@@ -41,6 +43,7 @@ from sqlalchemy import (
 )
 from sqlalchemy.engine.url import URL
 from sqlalchemy.orm import backref, relationship
+from sqlalchemy.sql.elements import ColumnElement, literal_column
 
 from superset import security_manager
 from superset.jinja_context import BaseTemplateProcessor, get_template_processor
@@ -52,9 +55,10 @@ from superset.models.helpers import (
 )
 from superset.sql_parse import CtasMethod, ParsedQuery, Table
 from superset.sqllab.limiting_factor import LimitingFactor
-from superset.utils.core import GenericDataType, QueryStatus, user_label
+from superset.utils.core import get_column_name, QueryStatus, user_label
 
 if TYPE_CHECKING:
+    from superset.connectors.sqla.models import TableColumn
     from superset.db_engine_specs import BaseEngineSpec
 
 
@@ -129,9 +133,8 @@ class Query(
     def get_template_processor(self, **kwargs: Any) -> BaseTemplateProcessor:
         return get_template_processor(query=self, database=self.database, **kwargs)
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
-            "changedOn": self.changed_on,
             "changed_on": self.changed_on.isoformat(),
             "dbId": self.database_id,
             "db": self.database.database_name if self.database else None,
@@ -179,51 +182,36 @@ class Query(
         return self.user.username
 
     @property
-    def sql_tables(self) -> List[Table]:
+    def sql_tables(self) -> list[Table]:
         return list(ParsedQuery(self.sql).tables)
 
     @property
-    def columns(self) -> List[Dict[str, Any]]:
-        bool_types = ("BOOL",)
-        num_types = (
-            "DOUBLE",
-            "FLOAT",
-            "INT",
-            "BIGINT",
-            "NUMBER",
-            "LONG",
-            "REAL",
-            "NUMERIC",
-            "DECIMAL",
-            "MONEY",
+    def columns(self) -> list["TableColumn"]:
+        from superset.connectors.sqla.models import (  # pylint: disable=import-outside-toplevel
+            TableColumn,
         )
-        date_types = ("DATE", "TIME")
-        str_types = ("VARCHAR", "STRING", "CHAR")
-        columns = []
-        col_type = ""
-        for col in self.extra.get("columns", []):
-            computed_column = {**col}
-            col_type = col.get("type")
 
-            if col_type and any(map(lambda t: t in col_type.upper(), str_types)):
-                computed_column["type_generic"] = GenericDataType.STRING
-            if col_type and any(map(lambda t: t in col_type.upper(), bool_types)):
-                computed_column["type_generic"] = GenericDataType.BOOLEAN
-            if col_type and any(map(lambda t: t in col_type.upper(), num_types)):
-                computed_column["type_generic"] = GenericDataType.NUMERIC
-            if col_type and any(map(lambda t: t in col_type.upper(), date_types)):
-                computed_column["type_generic"] = GenericDataType.TEMPORAL
-
-            computed_column["column_name"] = col.get("name")
-            computed_column["groupby"] = True
-            columns.append(computed_column)
-        return columns
+        return [
+            TableColumn(
+                column_name=col["column_name"],
+                database=self.database,
+                is_dttm=col["is_dttm"],
+                filterable=True,
+                groupby=True,
+                type=col["type"],
+            )
+            for col in self.extra.get("columns", [])
+        ]
 
     @property
-    def data(self) -> Dict[str, Any]:
+    def db_extra(self) -> Optional[dict[str, Any]]:
+        return None
+
+    @property
+    def data(self) -> dict[str, Any]:
         order_by_choices = []
         for col in self.columns:
-            column_name = str(col.get("column_name") or "")
+            column_name = str(col.column_name or "")
             order_by_choices.append(
                 (json.dumps([column_name, True]), f"{column_name} " + __("[asc]"))
             )
@@ -237,7 +225,7 @@ class Query(
             ],
             "filter_select": True,
             "name": self.tab_name,
-            "columns": self.columns,
+            "columns": [o.data for o in self.columns],
             "metrics": [],
             "id": self.id,
             "type": self.type,
@@ -246,6 +234,7 @@ class Query(
             "database": {"id": self.database_id, "backend": self.database.backend},
             "order_by_choices": order_by_choices,
             "schema": self.schema,
+            "verbose_map": {},
         }
 
     def raise_for_access(self) -> None:
@@ -258,11 +247,13 @@ class Query(
         security_manager.raise_for_access(query=self)
 
     @property
-    def db_engine_spec(self) -> Type["BaseEngineSpec"]:
+    def db_engine_spec(
+        self,
+    ) -> builtins.type["BaseEngineSpec"]:  # pylint: disable=unsubscriptable-object
         return self.database.db_engine_spec
 
     @property
-    def owners_data(self) -> List[Dict[str, Any]]:
+    def owners_data(self) -> list[dict[str, Any]]:
         return []
 
     @property
@@ -278,8 +269,8 @@ class Query(
         return 0
 
     @property
-    def column_names(self) -> List[Any]:
-        return [col.get("column_name") for col in self.columns]
+    def column_names(self) -> list[Any]:
+        return [col.column_name for col in self.columns]
 
     @property
     def offset(self) -> int:
@@ -293,8 +284,8 @@ class Query(
         return None
 
     @property
-    def dttm_cols(self) -> List[Any]:
-        return [col.get("column_name") for col in self.columns if col.get("is_dttm")]
+    def dttm_cols(self) -> list[Any]:
+        return [col.column_name for col in self.columns if col.is_dttm]
 
     @property
     def schema_perm(self) -> str:
@@ -309,7 +300,7 @@ class Query(
         return ""
 
     @staticmethod
-    def get_extra_cache_keys(query_obj: Dict[str, Any]) -> List[str]:
+    def get_extra_cache_keys(query_obj: dict[str, Any]) -> list[Hashable]:
         return []
 
     @property
@@ -333,14 +324,37 @@ class Query(
     def tracking_url(self, value: str) -> None:
         self.tracking_url_raw = value
 
-    def get_column(self, column_name: Optional[str]) -> Optional[Dict[str, Any]]:
+    def get_column(self, column_name: Optional[str]) -> Optional[dict[str, Any]]:
         if not column_name:
             return None
         for col in self.columns:
-            if col.get("column_name") == column_name:
+            if col.column_name == column_name:
                 return col
         return None
 
+    def adhoc_column_to_sqla(
+        self,
+        col: "AdhocColumn",  # type: ignore
+        force_type_check: bool = False,
+        template_processor: Optional[BaseTemplateProcessor] = None,
+    ) -> ColumnElement:
+        """
+        Turn an adhoc column into a sqlalchemy column.
+        :param col: Adhoc column definition
+        :param template_processor: template_processor instance
+        :returns: The metric defined as a sqlalchemy column
+        :rtype: sqlalchemy.sql.column
+        """
+        label = get_column_name(col)
+        expression = self._process_sql_expression(
+            expression=col["sqlExpression"],
+            database_id=self.database_id,
+            schema=self.schema,
+            template_processor=template_processor,
+        )
+        sqla_column = literal_column(expression)
+        return self.make_sqla_column_compatible(sqla_column, label)
+
 
 class SavedQuery(Model, AuditMixinNullable, ExtraJSONMixin, ImportExportMixin):
     """ORM model for SQL query"""
@@ -366,6 +380,14 @@ class SavedQuery(Model, AuditMixinNullable, ExtraJSONMixin, ImportExportMixin):
     )
     rows = Column(Integer, nullable=True)
     last_run = Column(DateTime, nullable=True)
+    tags = relationship(
+        "Tag",
+        secondary="tagged_object",
+        overlaps="tags",
+        primaryjoin="and_(SavedQuery.id == TaggedObject.object_id)",
+        secondaryjoin="and_(TaggedObject.tag_id == Tag.id, "
+        "TaggedObject.object_type == 'query')",
+    )
 
     export_parent = "database"
     export_fields = [
@@ -378,7 +400,7 @@ class SavedQuery(Model, AuditMixinNullable, ExtraJSONMixin, ImportExportMixin):
     def __repr__(self) -> str:
         return str(self.label)
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "id": self.id,
         }
@@ -402,10 +424,10 @@ class SavedQuery(Model, AuditMixinNullable, ExtraJSONMixin, ImportExportMixin):
         return self.database.sqlalchemy_uri
 
     def url(self) -> str:
-        return "/superset/sqllab?savedQueryId={0}".format(self.id)
+        return f"/superset/sqllab?savedQueryId={self.id}"
 
     @property
-    def sql_tables(self) -> List[Table]:
+    def sql_tables(self) -> list[Table]:
         return list(ParsedQuery(self.sql).tables)
 
     @property
@@ -422,7 +444,6 @@ class SavedQuery(Model, AuditMixinNullable, ExtraJSONMixin, ImportExportMixin):
 
 
 class TabState(Model, AuditMixinNullable, ExtraJSONMixin):
-
     __tablename__ = "tab_state"
 
     # basic info
@@ -465,7 +486,7 @@ class TabState(Model, AuditMixinNullable, ExtraJSONMixin):
     )
     saved_query = relationship("SavedQuery", foreign_keys=[saved_query_id])
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "id": self.id,
             "user_id": self.user_id,
@@ -481,11 +502,11 @@ class TabState(Model, AuditMixinNullable, ExtraJSONMixin):
             "template_params": self.template_params,
             "hide_left_bar": self.hide_left_bar,
             "saved_query": self.saved_query.to_dict() if self.saved_query else None,
+            "extra_json": self.extra,
         }
 
 
 class TableSchema(Model, AuditMixinNullable, ExtraJSONMixin):
-
     __tablename__ = "table_schema"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
@@ -503,7 +524,7 @@ class TableSchema(Model, AuditMixinNullable, ExtraJSONMixin):
 
     expanded = Column(Boolean, default=False)
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         try:
             description = json.loads(self.description)
         except json.JSONDecodeError:
