@@ -19,7 +19,7 @@ from __future__ import annotations
 
 import importlib
 import logging
-from typing import Callable, Dict, TYPE_CHECKING
+from typing import Callable, TYPE_CHECKING
 
 from flask import current_app, Flask, request, Response, session
 from flask_login import login_user
@@ -52,7 +52,7 @@ class MachineAuthProvider:
         :return: The WebDriver passed in (fluent)
         """
         # Short-circuit this method if we have an override configured
-        if self._auth_webdriver_func_override is not None:
+        if self._auth_webdriver_func_override:  # type: ignore
             return self._auth_webdriver_func_override(driver, user)
 
         # Setting cookies requires doing a request first
@@ -71,7 +71,7 @@ class MachineAuthProvider:
         return driver
 
     @staticmethod
-    def get_auth_cookies(user: User) -> Dict[str, str]:
+    def get_auth_cookies(user: User) -> dict[str, str]:
         # Login with the user specified to get the reports
         with current_app.test_request_context("/login"):
             login_user(user)
