@@ -61,7 +61,7 @@ REDIS_CELERY_DB = os.environ.get("REDIS_CELERY_DB", 2)
 REDIS_RESULTS_DB = os.environ.get("REDIS_RESULTS_DB", 3)
 
 
-class CeleryConfig(object):
+class CeleryConfig:
     BROKER_URL = f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_CELERY_DB}"
     CELERY_IMPORTS = ("superset.sql_lab", "superset.tasks.thumbnails")
     CELERY_ANNOTATIONS = {"sql_lab.add": {"rate_limit": "10/s"}}
