@@ -18,19 +18,26 @@
 
 import copy
 
+import pytest
+from pytest_mock import MockFixture
 from sqlalchemy.orm.session import Session
 
+from superset.commands.exceptions import ImportFailedError
 
-def test_import_chart(session: Session) -> None:
+
+def test_import_chart(mocker: MockFixture, session: Session) -> None:
     """
     Test importing a chart.
     """
+    from superset import security_manager
     from superset.charts.commands.importers.v1.utils import import_chart
     from superset.connectors.sqla.models import SqlaTable
     from superset.models.core import Database
     from superset.models.slice import Slice
     from tests.integration_tests.fixtures.importexport import chart_config
 
+    mocker.patch.object(security_manager, "can_access", return_value=True)
+
     engine = session.get_bind()
     Slice.metadata.create_all(engine)  # pylint: disable=no-member
 
@@ -45,16 +52,19 @@ def test_import_chart(session: Session) -> None:
     assert chart.external_url is None
 
 
-def test_import_chart_managed_externally(session: Session) -> None:
+def test_import_chart_managed_externally(mocker: MockFixture, session: Session) -> None:
     """
     Test importing a chart that is managed externally.
     """
+    from superset import security_manager
     from superset.charts.commands.importers.v1.utils import import_chart
     from superset.connectors.sqla.models import SqlaTable
     from superset.models.core import Database
     from superset.models.slice import Slice
     from tests.integration_tests.fixtures.importexport import chart_config
 
+    mocker.patch.object(security_manager, "can_access", return_value=True)
+
     engine = session.get_bind()
     Slice.metadata.create_all(engine)  # pylint: disable=no-member
 
@@ -67,3 +77,34 @@ def test_import_chart_managed_externally(session: Session) -> None:
     chart = import_chart(session, config)
     assert chart.is_managed_externally is True
     assert chart.external_url == "https://example.org/my_chart"
+
+
+def test_import_chart_without_permission(
+    mocker: MockFixture,
+    session: Session,
+) -> None:
+    """
+    Test importing a chart when a user doesn't have permissions to create.
+    """
+    from superset import security_manager
+    from superset.charts.commands.importers.v1.utils import import_chart
+    from superset.connectors.sqla.models import SqlaTable
+    from superset.models.core import Database
+    from superset.models.slice import Slice
+    from tests.integration_tests.fixtures.importexport import chart_config
+
+    mocker.patch.object(security_manager, "can_access", return_value=False)
+
+    engine = session.get_bind()
+    Slice.metadata.create_all(engine)  # pylint: disable=no-member
+
+    config = copy.deepcopy(chart_config)
+    config["datasource_id"] = 1
+    config["datasource_type"] = "table"
+
+    with pytest.raises(ImportFailedError) as excinfo:
+        import_chart(session, config)
+    assert (
+        str(excinfo.value)
+        == "Chart doesn't exist and user doesn't have permission to create charts"
+    )
